module IBUF(O, I);
	input I;
	output O;

	assign O = I;
endmodule

module IOBUF(O, IO, I, T);
	input T;
	input I;
	output O;
	inout IO;

	assign IO = T ? 1'bz : I;
	assign O = IO;
endmodule

module BUFG(O, I);
	input I;
	output O;

	assign O = I;
endmodule

module OBUF(O, I);
	input I;
	output O;

	assign O = I;
endmodule

module IBUFG(I, O);
	input I;
	output O;

	assign O = I;
endmodule

module OBUFT(I, O, T);
	input I;
	input T;
	output O;

	assign O = T ? 1'bz : I;
endmodule

module OBUFE(O, E, I);
	input I;
	input E;
	output O;

	assign O = E ? I : 1'bz;
endmodule

module IOBUFE(O, IO, I, E);
	input I;
	input E;
	inout IO;
	output O;

	assign O = IO;
	assign IO = E ? 1'bz : I;
endmodule

module IOBUFE8(O, IO, I, E);
	input [7:0] I;
	input E;
	inout [7:0] IO;
	output [7:0] O;

	IOBUFE buf0(O[0], IO[0], I[0], E);
	IOBUFE buf1(O[1], IO[1], I[1], E);
	IOBUFE buf2(O[2], IO[2], I[2], E);
	IOBUFE buf3(O[3], IO[3], I[3], E);
	IOBUFE buf4(O[4], IO[4], I[4], E);
	IOBUFE buf5(O[5], IO[5], I[5], E);
	IOBUFE buf6(O[6], IO[6], I[6], E);
	IOBUFE buf7(O[7], IO[7], I[7], E);
endmodule

module RAM16X1D(DPO, SPO, A0, A1, A2, A3, D, DPRA0, DPRA1, DPRA2, DPRA3, WCLK, WE);

parameter [15:0] INIT = 16'h0000;

input D;		/* Data In */
input WE;		/* Write Enable for port A */
input WCLK;		/* Clock for port A */
input A0;		/* Address for port A, bit 0 */
input A1;		/* Address for port A, bit 1 */
input A2;		/* Address for port A, bit 2 */
input A3;		/* Address for port A, bit 3 */
input DPRA0;		/* Address for port B, bit 0 */
input DPRA1;		/* Address for port B, bit 1 */
input DPRA2;		/* Address for port B, bit 2 */
input DPRA3;		/* Address for port B, bit 3 */
output SPO;		/* port A data out */
output DPO;		/* port B data out */

wire [3:0] A;
wire [3:0] DPRA;

assign A = { A3, A2, A1, A0 };
assign DPRA = { DPRA3, DPRA2, DPRA1, DPRA0 };

reg dp[0:15];

assign SPO = dp[A];
assign DPO = dp[DPRA];

integer i;
initial begin
	dp[0] = INIT[0];
	dp[1] = INIT[1];
	dp[2] = INIT[2];
	dp[3] = INIT[3];
	dp[4] = INIT[4];
	dp[5] = INIT[5];
	dp[6] = INIT[6];
	dp[7] = INIT[7];
	dp[8] = INIT[8];
	dp[9] = INIT[9];
	dp[10] = INIT[10];
	dp[11] = INIT[11];
	dp[12] = INIT[12];
	dp[13] = INIT[13];
	dp[14] = INIT[14];
	dp[15] = INIT[15];
end

always @(posedge WCLK) begin
	if (WE)
		dp[A] <= D;
end

endmodule

module RAM16X1S(O, A0, A1, A2, A3, D, WCLK, WE);

parameter [15:0] INIT = 16'h0000;

input D;		/* Data In */
input WE;		/* Write Enable for port A */
input WCLK;		/* Clock for port A */
input A0;		/* Address for port A, bit 0 */
input A1;		/* Address for port A, bit 1 */
input A2;		/* Address for port A, bit 2 */
input A3;		/* Address for port A, bit 3 */
output O;		/* port A data out */

wire [3:0] A;

assign A = { A3, A2, A1, A0 };

reg dp[0:15];

assign O = dp[A];

integer i;
initial begin
	dp[0] = INIT[0];
	dp[1] = INIT[1];
	dp[2] = INIT[2];
	dp[3] = INIT[3];
	dp[4] = INIT[4];
	dp[5] = INIT[5];
	dp[6] = INIT[6];
	dp[7] = INIT[7];
	dp[8] = INIT[8];
	dp[9] = INIT[9];
	dp[10] = INIT[10];
	dp[11] = INIT[11];
	dp[12] = INIT[12];
	dp[13] = INIT[13];
	dp[14] = INIT[14];
	dp[15] = INIT[15];
end

always @(posedge WCLK) begin
	if (WE)
		dp[A] <= D;
end

endmodule

module RAM32X1S(O, A0, A1, A2, A3, A4, D, WCLK, WE);

parameter [31:0] INIT = 32'h00000000;

input D;		/* Data In */
input WE;		/* Write Enable for port A */
input WCLK;		/* Clock for port A */
input A0;		/* Address for port A, bit 0 */
input A1;		/* Address for port A, bit 1 */
input A2;		/* Address for port A, bit 2 */
input A3;		/* Address for port A, bit 3 */
input A4;		/* Address for port A, bit 4 */
output O;		/* port A data out */

wire [4:0] A;

assign A = { A4, A3, A2, A1, A0 };

reg dp[0:31];

assign O = dp[A];

integer i;
initial begin
	dp[0] = INIT[0];
	dp[1] = INIT[1];
	dp[2] = INIT[2];
	dp[3] = INIT[3];
	dp[4] = INIT[4];
	dp[5] = INIT[5];
	dp[6] = INIT[6];
	dp[7] = INIT[7];
	dp[8] = INIT[8];
	dp[9] = INIT[9];
	dp[10] = INIT[10];
	dp[11] = INIT[11];
	dp[12] = INIT[12];
	dp[13] = INIT[13];
	dp[14] = INIT[14];
	dp[15] = INIT[15];
	dp[16] = INIT[16];
	dp[17] = INIT[17];
	dp[18] = INIT[18];
	dp[19] = INIT[19];
	dp[20] = INIT[20];
	dp[21] = INIT[21];
	dp[22] = INIT[22];
	dp[23] = INIT[23];
	dp[24] = INIT[24];
	dp[25] = INIT[25];
	dp[26] = INIT[26];
	dp[27] = INIT[27];
	dp[28] = INIT[28];
	dp[29] = INIT[29];
	dp[30] = INIT[30];
	dp[31] = INIT[31];
end

always @(posedge WCLK) begin
	if (WE)
		dp[A] <= D;
end

endmodule

module RAM64X1S(O, A0, A1, A2, A3, A4, A5, D, WCLK, WE);

parameter [63:0] INIT = 32'h00000000;

input D;		/* Data In */
input WE;		/* Write Enable for port A */
input WCLK;		/* Clock for port A */
input A0;		/* Address for port A, bit 0 */
input A1;		/* Address for port A, bit 1 */
input A2;		/* Address for port A, bit 2 */
input A3;		/* Address for port A, bit 3 */
input A4;		/* Address for port A, bit 4 */
input A5;		/* Address for port A, bit 5 */
output O;		/* port A data out */

wire [5:0] A;

assign A = { A5, A4, A3, A2, A1, A0 };

reg dp[0:63];

assign O = dp[A];

integer i;
initial begin
	dp[0] = INIT[0];
	dp[1] = INIT[1];
	dp[2] = INIT[2];
	dp[3] = INIT[3];
	dp[4] = INIT[4];
	dp[5] = INIT[5];
	dp[6] = INIT[6];
	dp[7] = INIT[7];
	dp[8] = INIT[8];
	dp[9] = INIT[9];
	dp[10] = INIT[10];
	dp[11] = INIT[11];
	dp[12] = INIT[12];
	dp[13] = INIT[13];
	dp[14] = INIT[14];
	dp[15] = INIT[15];
	dp[16] = INIT[16];
	dp[17] = INIT[17];
	dp[18] = INIT[18];
	dp[19] = INIT[19];
	dp[20] = INIT[20];
	dp[21] = INIT[21];
	dp[22] = INIT[22];
	dp[23] = INIT[23];
	dp[24] = INIT[24];
	dp[25] = INIT[25];
	dp[26] = INIT[26];
	dp[27] = INIT[27];
	dp[28] = INIT[28];
	dp[29] = INIT[29];
	dp[30] = INIT[30];
	dp[31] = INIT[31];
	dp[32] = INIT[32];
	dp[33] = INIT[33];
	dp[34] = INIT[34];
	dp[35] = INIT[35];
	dp[36] = INIT[36];
	dp[37] = INIT[37];
	dp[38] = INIT[38];
	dp[39] = INIT[39];
	dp[40] = INIT[40];
	dp[41] = INIT[41];
	dp[42] = INIT[42];
	dp[43] = INIT[43];
	dp[44] = INIT[44];
	dp[45] = INIT[45];
	dp[46] = INIT[46];
	dp[47] = INIT[47];
	dp[48] = INIT[48];
	dp[49] = INIT[49];
	dp[50] = INIT[50];
	dp[51] = INIT[51];
	dp[52] = INIT[52];
	dp[53] = INIT[53];
	dp[54] = INIT[54];
	dp[55] = INIT[55];
	dp[56] = INIT[56];
	dp[57] = INIT[57];
	dp[58] = INIT[58];
	dp[59] = INIT[59];
	dp[60] = INIT[60];
	dp[61] = INIT[61];
	dp[62] = INIT[62];
	dp[63] = INIT[63];
end

always @(posedge WCLK) begin
	if (WE)
		dp[A] <= D;
end

endmodule

module RAMB16BWE_S18(DO, DOP, DI, DIP, ADDR, WE, EN, SSR, CLK);

parameter [17:0] SRVAL = 0;
parameter [255:0] INIT_00 = 0;
parameter [255:0] INIT_01 = 0;
parameter [255:0] INIT_02 = 0;
parameter [255:0] INIT_03 = 0;
parameter [255:0] INIT_04 = 0;
parameter [255:0] INIT_05 = 0;
parameter [255:0] INIT_06 = 0;
parameter [255:0] INIT_07 = 0;
parameter [255:0] INIT_08 = 0;
parameter [255:0] INIT_09 = 0;
parameter [255:0] INIT_0A = 0;
parameter [255:0] INIT_0B = 0;
parameter [255:0] INIT_0C = 0;
parameter [255:0] INIT_0D = 0;
parameter [255:0] INIT_0E = 0;
parameter [255:0] INIT_0F = 0;
parameter [255:0] INIT_10 = 0;
parameter [255:0] INIT_11 = 0;
parameter [255:0] INIT_12 = 0;
parameter [255:0] INIT_13 = 0;
parameter [255:0] INIT_14 = 0;
parameter [255:0] INIT_15 = 0;
parameter [255:0] INIT_16 = 0;
parameter [255:0] INIT_17 = 0;
parameter [255:0] INIT_18 = 0;
parameter [255:0] INIT_19 = 0;
parameter [255:0] INIT_1A = 0;
parameter [255:0] INIT_1B = 0;
parameter [255:0] INIT_1C = 0;
parameter [255:0] INIT_1D = 0;
parameter [255:0] INIT_1E = 0;
parameter [255:0] INIT_1F = 0;
parameter [255:0] INIT_20 = 0;
parameter [255:0] INIT_21 = 0;
parameter [255:0] INIT_22 = 0;
parameter [255:0] INIT_23 = 0;
parameter [255:0] INIT_24 = 0;
parameter [255:0] INIT_25 = 0;
parameter [255:0] INIT_26 = 0;
parameter [255:0] INIT_27 = 0;
parameter [255:0] INIT_28 = 0;
parameter [255:0] INIT_29 = 0;
parameter [255:0] INIT_2A = 0;
parameter [255:0] INIT_2B = 0;
parameter [255:0] INIT_2C = 0;
parameter [255:0] INIT_2D = 0;
parameter [255:0] INIT_2E = 0;
parameter [255:0] INIT_2F = 0;
parameter [255:0] INIT_30 = 0;
parameter [255:0] INIT_31 = 0;
parameter [255:0] INIT_32 = 0;
parameter [255:0] INIT_33 = 0;
parameter [255:0] INIT_34 = 0;
parameter [255:0] INIT_35 = 0;
parameter [255:0] INIT_36 = 0;
parameter [255:0] INIT_37 = 0;
parameter [255:0] INIT_38 = 0;
parameter [255:0] INIT_39 = 0;
parameter [255:0] INIT_3A = 0;
parameter [255:0] INIT_3B = 0;
parameter [255:0] INIT_3C = 0;
parameter [255:0] INIT_3D = 0;
parameter [255:0] INIT_3E = 0;
parameter [255:0] INIT_3F = 0;
parameter [255:0] INITP_00 = 0;
parameter [255:0] INITP_01 = 0;
parameter [255:0] INITP_02 = 0;
parameter [255:0] INITP_03 = 0;
parameter [255:0] INITP_04 = 0;
parameter [255:0] INITP_05 = 0;
parameter [255:0] INITP_06 = 0;
parameter [255:0] INITP_07 = 0;

output [15:0] DO;
output [1:0] DOP;
input [15:0] DI;
input [1:0] DIP;
input [9:0] ADDR;
input [1:0] WE;
input EN;
input SSR;
input CLK;

reg [15:0] data[0:1023];
reg [1:0] parity[0:1023];

wire [15:0] data_a = data[ADDR];
wire [1:0] parity_a = parity[ADDR];

always @(posedge CLK)
	if (EN) begin
		case (WE)
		0: ;
		1: data[ADDR] <= { data_a[15:8], DI[7:0] };
		2: data[ADDR] <= { DI[15:8], data_a[7:0] };
		3: data[ADDR] <= DI;
		endcase
	end

always @(posedge CLK)
	if (EN) begin
		case (WE)
		0: ;
		1: parity[ADDR] <= { parity_a[1], DIP[0] };
		2: parity[ADDR] <= { DIP[1], parity_a[0] };
		3: parity[ADDR] <= DIP;
		endcase
	end

reg [15:0] DO = 0;
always @(posedge CLK)
	if (EN) begin
		if (SSR)
			DO <= SRVAL[15:0];
		else
			DO <= data_a;
	end

initial begin
	data[0] = INIT_00[15:0];
	data[1] = INIT_00[31:16];
	data[2] = INIT_00[47:32];
	data[3] = INIT_00[63:48];
	data[4] = INIT_00[79:64];
	data[5] = INIT_00[95:80];
	data[6] = INIT_00[111:96];
	data[7] = INIT_00[127:112];
	data[8] = INIT_00[143:128];
	data[9] = INIT_00[159:144];
	data[10] = INIT_00[175:160];
	data[11] = INIT_00[191:176];
	data[12] = INIT_00[207:192];
	data[13] = INIT_00[223:208];
	data[14] = INIT_00[239:224];
	data[15] = INIT_00[255:240];
	data[16] = INIT_01[15:0];
	data[17] = INIT_01[31:16];
	data[18] = INIT_01[47:32];
	data[19] = INIT_01[63:48];
	data[20] = INIT_01[79:64];
	data[21] = INIT_01[95:80];
	data[22] = INIT_01[111:96];
	data[23] = INIT_01[127:112];
	data[24] = INIT_01[143:128];
	data[25] = INIT_01[159:144];
	data[26] = INIT_01[175:160];
	data[27] = INIT_01[191:176];
	data[28] = INIT_01[207:192];
	data[29] = INIT_01[223:208];
	data[30] = INIT_01[239:224];
	data[31] = INIT_01[255:240];
	data[32] = INIT_02[15:0];
	data[33] = INIT_02[31:16];
	data[34] = INIT_02[47:32];
	data[35] = INIT_02[63:48];
	data[36] = INIT_02[79:64];
	data[37] = INIT_02[95:80];
	data[38] = INIT_02[111:96];
	data[39] = INIT_02[127:112];
	data[40] = INIT_02[143:128];
	data[41] = INIT_02[159:144];
	data[42] = INIT_02[175:160];
	data[43] = INIT_02[191:176];
	data[44] = INIT_02[207:192];
	data[45] = INIT_02[223:208];
	data[46] = INIT_02[239:224];
	data[47] = INIT_02[255:240];
	data[48] = INIT_03[15:0];
	data[49] = INIT_03[31:16];
	data[50] = INIT_03[47:32];
	data[51] = INIT_03[63:48];
	data[52] = INIT_03[79:64];
	data[53] = INIT_03[95:80];
	data[54] = INIT_03[111:96];
	data[55] = INIT_03[127:112];
	data[56] = INIT_03[143:128];
	data[57] = INIT_03[159:144];
	data[58] = INIT_03[175:160];
	data[59] = INIT_03[191:176];
	data[60] = INIT_03[207:192];
	data[61] = INIT_03[223:208];
	data[62] = INIT_03[239:224];
	data[63] = INIT_03[255:240];
	data[64] = INIT_04[15:0];
	data[65] = INIT_04[31:16];
	data[66] = INIT_04[47:32];
	data[67] = INIT_04[63:48];
	data[68] = INIT_04[79:64];
	data[69] = INIT_04[95:80];
	data[70] = INIT_04[111:96];
	data[71] = INIT_04[127:112];
	data[72] = INIT_04[143:128];
	data[73] = INIT_04[159:144];
	data[74] = INIT_04[175:160];
	data[75] = INIT_04[191:176];
	data[76] = INIT_04[207:192];
	data[77] = INIT_04[223:208];
	data[78] = INIT_04[239:224];
	data[79] = INIT_04[255:240];
	data[80] = INIT_05[15:0];
	data[81] = INIT_05[31:16];
	data[82] = INIT_05[47:32];
	data[83] = INIT_05[63:48];
	data[84] = INIT_05[79:64];
	data[85] = INIT_05[95:80];
	data[86] = INIT_05[111:96];
	data[87] = INIT_05[127:112];
	data[88] = INIT_05[143:128];
	data[89] = INIT_05[159:144];
	data[90] = INIT_05[175:160];
	data[91] = INIT_05[191:176];
	data[92] = INIT_05[207:192];
	data[93] = INIT_05[223:208];
	data[94] = INIT_05[239:224];
	data[95] = INIT_05[255:240];
	data[96] = INIT_06[15:0];
	data[97] = INIT_06[31:16];
	data[98] = INIT_06[47:32];
	data[99] = INIT_06[63:48];
	data[100] = INIT_06[79:64];
	data[101] = INIT_06[95:80];
	data[102] = INIT_06[111:96];
	data[103] = INIT_06[127:112];
	data[104] = INIT_06[143:128];
	data[105] = INIT_06[159:144];
	data[106] = INIT_06[175:160];
	data[107] = INIT_06[191:176];
	data[108] = INIT_06[207:192];
	data[109] = INIT_06[223:208];
	data[110] = INIT_06[239:224];
	data[111] = INIT_06[255:240];
	data[112] = INIT_07[15:0];
	data[113] = INIT_07[31:16];
	data[114] = INIT_07[47:32];
	data[115] = INIT_07[63:48];
	data[116] = INIT_07[79:64];
	data[117] = INIT_07[95:80];
	data[118] = INIT_07[111:96];
	data[119] = INIT_07[127:112];
	data[120] = INIT_07[143:128];
	data[121] = INIT_07[159:144];
	data[122] = INIT_07[175:160];
	data[123] = INIT_07[191:176];
	data[124] = INIT_07[207:192];
	data[125] = INIT_07[223:208];
	data[126] = INIT_07[239:224];
	data[127] = INIT_07[255:240];
	data[128] = INIT_08[15:0];
	data[129] = INIT_08[31:16];
	data[130] = INIT_08[47:32];
	data[131] = INIT_08[63:48];
	data[132] = INIT_08[79:64];
	data[133] = INIT_08[95:80];
	data[134] = INIT_08[111:96];
	data[135] = INIT_08[127:112];
	data[136] = INIT_08[143:128];
	data[137] = INIT_08[159:144];
	data[138] = INIT_08[175:160];
	data[139] = INIT_08[191:176];
	data[140] = INIT_08[207:192];
	data[141] = INIT_08[223:208];
	data[142] = INIT_08[239:224];
	data[143] = INIT_08[255:240];
	data[144] = INIT_09[15:0];
	data[145] = INIT_09[31:16];
	data[146] = INIT_09[47:32];
	data[147] = INIT_09[63:48];
	data[148] = INIT_09[79:64];
	data[149] = INIT_09[95:80];
	data[150] = INIT_09[111:96];
	data[151] = INIT_09[127:112];
	data[152] = INIT_09[143:128];
	data[153] = INIT_09[159:144];
	data[154] = INIT_09[175:160];
	data[155] = INIT_09[191:176];
	data[156] = INIT_09[207:192];
	data[157] = INIT_09[223:208];
	data[158] = INIT_09[239:224];
	data[159] = INIT_09[255:240];
	data[160] = INIT_0A[15:0];
	data[161] = INIT_0A[31:16];
	data[162] = INIT_0A[47:32];
	data[163] = INIT_0A[63:48];
	data[164] = INIT_0A[79:64];
	data[165] = INIT_0A[95:80];
	data[166] = INIT_0A[111:96];
	data[167] = INIT_0A[127:112];
	data[168] = INIT_0A[143:128];
	data[169] = INIT_0A[159:144];
	data[170] = INIT_0A[175:160];
	data[171] = INIT_0A[191:176];
	data[172] = INIT_0A[207:192];
	data[173] = INIT_0A[223:208];
	data[174] = INIT_0A[239:224];
	data[175] = INIT_0A[255:240];
	data[176] = INIT_0B[15:0];
	data[177] = INIT_0B[31:16];
	data[178] = INIT_0B[47:32];
	data[179] = INIT_0B[63:48];
	data[180] = INIT_0B[79:64];
	data[181] = INIT_0B[95:80];
	data[182] = INIT_0B[111:96];
	data[183] = INIT_0B[127:112];
	data[184] = INIT_0B[143:128];
	data[185] = INIT_0B[159:144];
	data[186] = INIT_0B[175:160];
	data[187] = INIT_0B[191:176];
	data[188] = INIT_0B[207:192];
	data[189] = INIT_0B[223:208];
	data[190] = INIT_0B[239:224];
	data[191] = INIT_0B[255:240];
	data[192] = INIT_0C[15:0];
	data[193] = INIT_0C[31:16];
	data[194] = INIT_0C[47:32];
	data[195] = INIT_0C[63:48];
	data[196] = INIT_0C[79:64];
	data[197] = INIT_0C[95:80];
	data[198] = INIT_0C[111:96];
	data[199] = INIT_0C[127:112];
	data[200] = INIT_0C[143:128];
	data[201] = INIT_0C[159:144];
	data[202] = INIT_0C[175:160];
	data[203] = INIT_0C[191:176];
	data[204] = INIT_0C[207:192];
	data[205] = INIT_0C[223:208];
	data[206] = INIT_0C[239:224];
	data[207] = INIT_0C[255:240];
	data[208] = INIT_0D[15:0];
	data[209] = INIT_0D[31:16];
	data[210] = INIT_0D[47:32];
	data[211] = INIT_0D[63:48];
	data[212] = INIT_0D[79:64];
	data[213] = INIT_0D[95:80];
	data[214] = INIT_0D[111:96];
	data[215] = INIT_0D[127:112];
	data[216] = INIT_0D[143:128];
	data[217] = INIT_0D[159:144];
	data[218] = INIT_0D[175:160];
	data[219] = INIT_0D[191:176];
	data[220] = INIT_0D[207:192];
	data[221] = INIT_0D[223:208];
	data[222] = INIT_0D[239:224];
	data[223] = INIT_0D[255:240];
	data[224] = INIT_0E[15:0];
	data[225] = INIT_0E[31:16];
	data[226] = INIT_0E[47:32];
	data[227] = INIT_0E[63:48];
	data[228] = INIT_0E[79:64];
	data[229] = INIT_0E[95:80];
	data[230] = INIT_0E[111:96];
	data[231] = INIT_0E[127:112];
	data[232] = INIT_0E[143:128];
	data[233] = INIT_0E[159:144];
	data[234] = INIT_0E[175:160];
	data[235] = INIT_0E[191:176];
	data[236] = INIT_0E[207:192];
	data[237] = INIT_0E[223:208];
	data[238] = INIT_0E[239:224];
	data[239] = INIT_0E[255:240];
	data[240] = INIT_0F[15:0];
	data[241] = INIT_0F[31:16];
	data[242] = INIT_0F[47:32];
	data[243] = INIT_0F[63:48];
	data[244] = INIT_0F[79:64];
	data[245] = INIT_0F[95:80];
	data[246] = INIT_0F[111:96];
	data[247] = INIT_0F[127:112];
	data[248] = INIT_0F[143:128];
	data[249] = INIT_0F[159:144];
	data[250] = INIT_0F[175:160];
	data[251] = INIT_0F[191:176];
	data[252] = INIT_0F[207:192];
	data[253] = INIT_0F[223:208];
	data[254] = INIT_0F[239:224];
	data[255] = INIT_0F[255:240];
	data[256] = INIT_10[15:0];
	data[257] = INIT_10[31:16];
	data[258] = INIT_10[47:32];
	data[259] = INIT_10[63:48];
	data[260] = INIT_10[79:64];
	data[261] = INIT_10[95:80];
	data[262] = INIT_10[111:96];
	data[263] = INIT_10[127:112];
	data[264] = INIT_10[143:128];
	data[265] = INIT_10[159:144];
	data[266] = INIT_10[175:160];
	data[267] = INIT_10[191:176];
	data[268] = INIT_10[207:192];
	data[269] = INIT_10[223:208];
	data[270] = INIT_10[239:224];
	data[271] = INIT_10[255:240];
	data[272] = INIT_11[15:0];
	data[273] = INIT_11[31:16];
	data[274] = INIT_11[47:32];
	data[275] = INIT_11[63:48];
	data[276] = INIT_11[79:64];
	data[277] = INIT_11[95:80];
	data[278] = INIT_11[111:96];
	data[279] = INIT_11[127:112];
	data[280] = INIT_11[143:128];
	data[281] = INIT_11[159:144];
	data[282] = INIT_11[175:160];
	data[283] = INIT_11[191:176];
	data[284] = INIT_11[207:192];
	data[285] = INIT_11[223:208];
	data[286] = INIT_11[239:224];
	data[287] = INIT_11[255:240];
	data[288] = INIT_12[15:0];
	data[289] = INIT_12[31:16];
	data[290] = INIT_12[47:32];
	data[291] = INIT_12[63:48];
	data[292] = INIT_12[79:64];
	data[293] = INIT_12[95:80];
	data[294] = INIT_12[111:96];
	data[295] = INIT_12[127:112];
	data[296] = INIT_12[143:128];
	data[297] = INIT_12[159:144];
	data[298] = INIT_12[175:160];
	data[299] = INIT_12[191:176];
	data[300] = INIT_12[207:192];
	data[301] = INIT_12[223:208];
	data[302] = INIT_12[239:224];
	data[303] = INIT_12[255:240];
	data[304] = INIT_13[15:0];
	data[305] = INIT_13[31:16];
	data[306] = INIT_13[47:32];
	data[307] = INIT_13[63:48];
	data[308] = INIT_13[79:64];
	data[309] = INIT_13[95:80];
	data[310] = INIT_13[111:96];
	data[311] = INIT_13[127:112];
	data[312] = INIT_13[143:128];
	data[313] = INIT_13[159:144];
	data[314] = INIT_13[175:160];
	data[315] = INIT_13[191:176];
	data[316] = INIT_13[207:192];
	data[317] = INIT_13[223:208];
	data[318] = INIT_13[239:224];
	data[319] = INIT_13[255:240];
	data[320] = INIT_14[15:0];
	data[321] = INIT_14[31:16];
	data[322] = INIT_14[47:32];
	data[323] = INIT_14[63:48];
	data[324] = INIT_14[79:64];
	data[325] = INIT_14[95:80];
	data[326] = INIT_14[111:96];
	data[327] = INIT_14[127:112];
	data[328] = INIT_14[143:128];
	data[329] = INIT_14[159:144];
	data[330] = INIT_14[175:160];
	data[331] = INIT_14[191:176];
	data[332] = INIT_14[207:192];
	data[333] = INIT_14[223:208];
	data[334] = INIT_14[239:224];
	data[335] = INIT_14[255:240];
	data[336] = INIT_15[15:0];
	data[337] = INIT_15[31:16];
	data[338] = INIT_15[47:32];
	data[339] = INIT_15[63:48];
	data[340] = INIT_15[79:64];
	data[341] = INIT_15[95:80];
	data[342] = INIT_15[111:96];
	data[343] = INIT_15[127:112];
	data[344] = INIT_15[143:128];
	data[345] = INIT_15[159:144];
	data[346] = INIT_15[175:160];
	data[347] = INIT_15[191:176];
	data[348] = INIT_15[207:192];
	data[349] = INIT_15[223:208];
	data[350] = INIT_15[239:224];
	data[351] = INIT_15[255:240];
	data[352] = INIT_16[15:0];
	data[353] = INIT_16[31:16];
	data[354] = INIT_16[47:32];
	data[355] = INIT_16[63:48];
	data[356] = INIT_16[79:64];
	data[357] = INIT_16[95:80];
	data[358] = INIT_16[111:96];
	data[359] = INIT_16[127:112];
	data[360] = INIT_16[143:128];
	data[361] = INIT_16[159:144];
	data[362] = INIT_16[175:160];
	data[363] = INIT_16[191:176];
	data[364] = INIT_16[207:192];
	data[365] = INIT_16[223:208];
	data[366] = INIT_16[239:224];
	data[367] = INIT_16[255:240];
	data[368] = INIT_17[15:0];
	data[369] = INIT_17[31:16];
	data[370] = INIT_17[47:32];
	data[371] = INIT_17[63:48];
	data[372] = INIT_17[79:64];
	data[373] = INIT_17[95:80];
	data[374] = INIT_17[111:96];
	data[375] = INIT_17[127:112];
	data[376] = INIT_17[143:128];
	data[377] = INIT_17[159:144];
	data[378] = INIT_17[175:160];
	data[379] = INIT_17[191:176];
	data[380] = INIT_17[207:192];
	data[381] = INIT_17[223:208];
	data[382] = INIT_17[239:224];
	data[383] = INIT_17[255:240];
	data[384] = INIT_18[15:0];
	data[385] = INIT_18[31:16];
	data[386] = INIT_18[47:32];
	data[387] = INIT_18[63:48];
	data[388] = INIT_18[79:64];
	data[389] = INIT_18[95:80];
	data[390] = INIT_18[111:96];
	data[391] = INIT_18[127:112];
	data[392] = INIT_18[143:128];
	data[393] = INIT_18[159:144];
	data[394] = INIT_18[175:160];
	data[395] = INIT_18[191:176];
	data[396] = INIT_18[207:192];
	data[397] = INIT_18[223:208];
	data[398] = INIT_18[239:224];
	data[399] = INIT_18[255:240];
	data[400] = INIT_19[15:0];
	data[401] = INIT_19[31:16];
	data[402] = INIT_19[47:32];
	data[403] = INIT_19[63:48];
	data[404] = INIT_19[79:64];
	data[405] = INIT_19[95:80];
	data[406] = INIT_19[111:96];
	data[407] = INIT_19[127:112];
	data[408] = INIT_19[143:128];
	data[409] = INIT_19[159:144];
	data[410] = INIT_19[175:160];
	data[411] = INIT_19[191:176];
	data[412] = INIT_19[207:192];
	data[413] = INIT_19[223:208];
	data[414] = INIT_19[239:224];
	data[415] = INIT_19[255:240];
	data[416] = INIT_1A[15:0];
	data[417] = INIT_1A[31:16];
	data[418] = INIT_1A[47:32];
	data[419] = INIT_1A[63:48];
	data[420] = INIT_1A[79:64];
	data[421] = INIT_1A[95:80];
	data[422] = INIT_1A[111:96];
	data[423] = INIT_1A[127:112];
	data[424] = INIT_1A[143:128];
	data[425] = INIT_1A[159:144];
	data[426] = INIT_1A[175:160];
	data[427] = INIT_1A[191:176];
	data[428] = INIT_1A[207:192];
	data[429] = INIT_1A[223:208];
	data[430] = INIT_1A[239:224];
	data[431] = INIT_1A[255:240];
	data[432] = INIT_1B[15:0];
	data[433] = INIT_1B[31:16];
	data[434] = INIT_1B[47:32];
	data[435] = INIT_1B[63:48];
	data[436] = INIT_1B[79:64];
	data[437] = INIT_1B[95:80];
	data[438] = INIT_1B[111:96];
	data[439] = INIT_1B[127:112];
	data[440] = INIT_1B[143:128];
	data[441] = INIT_1B[159:144];
	data[442] = INIT_1B[175:160];
	data[443] = INIT_1B[191:176];
	data[444] = INIT_1B[207:192];
	data[445] = INIT_1B[223:208];
	data[446] = INIT_1B[239:224];
	data[447] = INIT_1B[255:240];
	data[448] = INIT_1C[15:0];
	data[449] = INIT_1C[31:16];
	data[450] = INIT_1C[47:32];
	data[451] = INIT_1C[63:48];
	data[452] = INIT_1C[79:64];
	data[453] = INIT_1C[95:80];
	data[454] = INIT_1C[111:96];
	data[455] = INIT_1C[127:112];
	data[456] = INIT_1C[143:128];
	data[457] = INIT_1C[159:144];
	data[458] = INIT_1C[175:160];
	data[459] = INIT_1C[191:176];
	data[460] = INIT_1C[207:192];
	data[461] = INIT_1C[223:208];
	data[462] = INIT_1C[239:224];
	data[463] = INIT_1C[255:240];
	data[464] = INIT_1D[15:0];
	data[465] = INIT_1D[31:16];
	data[466] = INIT_1D[47:32];
	data[467] = INIT_1D[63:48];
	data[468] = INIT_1D[79:64];
	data[469] = INIT_1D[95:80];
	data[470] = INIT_1D[111:96];
	data[471] = INIT_1D[127:112];
	data[472] = INIT_1D[143:128];
	data[473] = INIT_1D[159:144];
	data[474] = INIT_1D[175:160];
	data[475] = INIT_1D[191:176];
	data[476] = INIT_1D[207:192];
	data[477] = INIT_1D[223:208];
	data[478] = INIT_1D[239:224];
	data[479] = INIT_1D[255:240];
	data[480] = INIT_1E[15:0];
	data[481] = INIT_1E[31:16];
	data[482] = INIT_1E[47:32];
	data[483] = INIT_1E[63:48];
	data[484] = INIT_1E[79:64];
	data[485] = INIT_1E[95:80];
	data[486] = INIT_1E[111:96];
	data[487] = INIT_1E[127:112];
	data[488] = INIT_1E[143:128];
	data[489] = INIT_1E[159:144];
	data[490] = INIT_1E[175:160];
	data[491] = INIT_1E[191:176];
	data[492] = INIT_1E[207:192];
	data[493] = INIT_1E[223:208];
	data[494] = INIT_1E[239:224];
	data[495] = INIT_1E[255:240];
	data[496] = INIT_1F[15:0];
	data[497] = INIT_1F[31:16];
	data[498] = INIT_1F[47:32];
	data[499] = INIT_1F[63:48];
	data[500] = INIT_1F[79:64];
	data[501] = INIT_1F[95:80];
	data[502] = INIT_1F[111:96];
	data[503] = INIT_1F[127:112];
	data[504] = INIT_1F[143:128];
	data[505] = INIT_1F[159:144];
	data[506] = INIT_1F[175:160];
	data[507] = INIT_1F[191:176];
	data[508] = INIT_1F[207:192];
	data[509] = INIT_1F[223:208];
	data[510] = INIT_1F[239:224];
	data[511] = INIT_1F[255:240];
	data[512] = INIT_20[15:0];
	data[513] = INIT_20[31:16];
	data[514] = INIT_20[47:32];
	data[515] = INIT_20[63:48];
	data[516] = INIT_20[79:64];
	data[517] = INIT_20[95:80];
	data[518] = INIT_20[111:96];
	data[519] = INIT_20[127:112];
	data[520] = INIT_20[143:128];
	data[521] = INIT_20[159:144];
	data[522] = INIT_20[175:160];
	data[523] = INIT_20[191:176];
	data[524] = INIT_20[207:192];
	data[525] = INIT_20[223:208];
	data[526] = INIT_20[239:224];
	data[527] = INIT_20[255:240];
	data[528] = INIT_21[15:0];
	data[529] = INIT_21[31:16];
	data[530] = INIT_21[47:32];
	data[531] = INIT_21[63:48];
	data[532] = INIT_21[79:64];
	data[533] = INIT_21[95:80];
	data[534] = INIT_21[111:96];
	data[535] = INIT_21[127:112];
	data[536] = INIT_21[143:128];
	data[537] = INIT_21[159:144];
	data[538] = INIT_21[175:160];
	data[539] = INIT_21[191:176];
	data[540] = INIT_21[207:192];
	data[541] = INIT_21[223:208];
	data[542] = INIT_21[239:224];
	data[543] = INIT_21[255:240];
	data[544] = INIT_22[15:0];
	data[545] = INIT_22[31:16];
	data[546] = INIT_22[47:32];
	data[547] = INIT_22[63:48];
	data[548] = INIT_22[79:64];
	data[549] = INIT_22[95:80];
	data[550] = INIT_22[111:96];
	data[551] = INIT_22[127:112];
	data[552] = INIT_22[143:128];
	data[553] = INIT_22[159:144];
	data[554] = INIT_22[175:160];
	data[555] = INIT_22[191:176];
	data[556] = INIT_22[207:192];
	data[557] = INIT_22[223:208];
	data[558] = INIT_22[239:224];
	data[559] = INIT_22[255:240];
	data[560] = INIT_23[15:0];
	data[561] = INIT_23[31:16];
	data[562] = INIT_23[47:32];
	data[563] = INIT_23[63:48];
	data[564] = INIT_23[79:64];
	data[565] = INIT_23[95:80];
	data[566] = INIT_23[111:96];
	data[567] = INIT_23[127:112];
	data[568] = INIT_23[143:128];
	data[569] = INIT_23[159:144];
	data[570] = INIT_23[175:160];
	data[571] = INIT_23[191:176];
	data[572] = INIT_23[207:192];
	data[573] = INIT_23[223:208];
	data[574] = INIT_23[239:224];
	data[575] = INIT_23[255:240];
	data[576] = INIT_24[15:0];
	data[577] = INIT_24[31:16];
	data[578] = INIT_24[47:32];
	data[579] = INIT_24[63:48];
	data[580] = INIT_24[79:64];
	data[581] = INIT_24[95:80];
	data[582] = INIT_24[111:96];
	data[583] = INIT_24[127:112];
	data[584] = INIT_24[143:128];
	data[585] = INIT_24[159:144];
	data[586] = INIT_24[175:160];
	data[587] = INIT_24[191:176];
	data[588] = INIT_24[207:192];
	data[589] = INIT_24[223:208];
	data[590] = INIT_24[239:224];
	data[591] = INIT_24[255:240];
	data[592] = INIT_25[15:0];
	data[593] = INIT_25[31:16];
	data[594] = INIT_25[47:32];
	data[595] = INIT_25[63:48];
	data[596] = INIT_25[79:64];
	data[597] = INIT_25[95:80];
	data[598] = INIT_25[111:96];
	data[599] = INIT_25[127:112];
	data[600] = INIT_25[143:128];
	data[601] = INIT_25[159:144];
	data[602] = INIT_25[175:160];
	data[603] = INIT_25[191:176];
	data[604] = INIT_25[207:192];
	data[605] = INIT_25[223:208];
	data[606] = INIT_25[239:224];
	data[607] = INIT_25[255:240];
	data[608] = INIT_26[15:0];
	data[609] = INIT_26[31:16];
	data[610] = INIT_26[47:32];
	data[611] = INIT_26[63:48];
	data[612] = INIT_26[79:64];
	data[613] = INIT_26[95:80];
	data[614] = INIT_26[111:96];
	data[615] = INIT_26[127:112];
	data[616] = INIT_26[143:128];
	data[617] = INIT_26[159:144];
	data[618] = INIT_26[175:160];
	data[619] = INIT_26[191:176];
	data[620] = INIT_26[207:192];
	data[621] = INIT_26[223:208];
	data[622] = INIT_26[239:224];
	data[623] = INIT_26[255:240];
	data[624] = INIT_27[15:0];
	data[625] = INIT_27[31:16];
	data[626] = INIT_27[47:32];
	data[627] = INIT_27[63:48];
	data[628] = INIT_27[79:64];
	data[629] = INIT_27[95:80];
	data[630] = INIT_27[111:96];
	data[631] = INIT_27[127:112];
	data[632] = INIT_27[143:128];
	data[633] = INIT_27[159:144];
	data[634] = INIT_27[175:160];
	data[635] = INIT_27[191:176];
	data[636] = INIT_27[207:192];
	data[637] = INIT_27[223:208];
	data[638] = INIT_27[239:224];
	data[639] = INIT_27[255:240];
	data[640] = INIT_28[15:0];
	data[641] = INIT_28[31:16];
	data[642] = INIT_28[47:32];
	data[643] = INIT_28[63:48];
	data[644] = INIT_28[79:64];
	data[645] = INIT_28[95:80];
	data[646] = INIT_28[111:96];
	data[647] = INIT_28[127:112];
	data[648] = INIT_28[143:128];
	data[649] = INIT_28[159:144];
	data[650] = INIT_28[175:160];
	data[651] = INIT_28[191:176];
	data[652] = INIT_28[207:192];
	data[653] = INIT_28[223:208];
	data[654] = INIT_28[239:224];
	data[655] = INIT_28[255:240];
	data[656] = INIT_29[15:0];
	data[657] = INIT_29[31:16];
	data[658] = INIT_29[47:32];
	data[659] = INIT_29[63:48];
	data[660] = INIT_29[79:64];
	data[661] = INIT_29[95:80];
	data[662] = INIT_29[111:96];
	data[663] = INIT_29[127:112];
	data[664] = INIT_29[143:128];
	data[665] = INIT_29[159:144];
	data[666] = INIT_29[175:160];
	data[667] = INIT_29[191:176];
	data[668] = INIT_29[207:192];
	data[669] = INIT_29[223:208];
	data[670] = INIT_29[239:224];
	data[671] = INIT_29[255:240];
	data[672] = INIT_2A[15:0];
	data[673] = INIT_2A[31:16];
	data[674] = INIT_2A[47:32];
	data[675] = INIT_2A[63:48];
	data[676] = INIT_2A[79:64];
	data[677] = INIT_2A[95:80];
	data[678] = INIT_2A[111:96];
	data[679] = INIT_2A[127:112];
	data[680] = INIT_2A[143:128];
	data[681] = INIT_2A[159:144];
	data[682] = INIT_2A[175:160];
	data[683] = INIT_2A[191:176];
	data[684] = INIT_2A[207:192];
	data[685] = INIT_2A[223:208];
	data[686] = INIT_2A[239:224];
	data[687] = INIT_2A[255:240];
	data[688] = INIT_2B[15:0];
	data[689] = INIT_2B[31:16];
	data[690] = INIT_2B[47:32];
	data[691] = INIT_2B[63:48];
	data[692] = INIT_2B[79:64];
	data[693] = INIT_2B[95:80];
	data[694] = INIT_2B[111:96];
	data[695] = INIT_2B[127:112];
	data[696] = INIT_2B[143:128];
	data[697] = INIT_2B[159:144];
	data[698] = INIT_2B[175:160];
	data[699] = INIT_2B[191:176];
	data[700] = INIT_2B[207:192];
	data[701] = INIT_2B[223:208];
	data[702] = INIT_2B[239:224];
	data[703] = INIT_2B[255:240];
	data[704] = INIT_2C[15:0];
	data[705] = INIT_2C[31:16];
	data[706] = INIT_2C[47:32];
	data[707] = INIT_2C[63:48];
	data[708] = INIT_2C[79:64];
	data[709] = INIT_2C[95:80];
	data[710] = INIT_2C[111:96];
	data[711] = INIT_2C[127:112];
	data[712] = INIT_2C[143:128];
	data[713] = INIT_2C[159:144];
	data[714] = INIT_2C[175:160];
	data[715] = INIT_2C[191:176];
	data[716] = INIT_2C[207:192];
	data[717] = INIT_2C[223:208];
	data[718] = INIT_2C[239:224];
	data[719] = INIT_2C[255:240];
	data[720] = INIT_2D[15:0];
	data[721] = INIT_2D[31:16];
	data[722] = INIT_2D[47:32];
	data[723] = INIT_2D[63:48];
	data[724] = INIT_2D[79:64];
	data[725] = INIT_2D[95:80];
	data[726] = INIT_2D[111:96];
	data[727] = INIT_2D[127:112];
	data[728] = INIT_2D[143:128];
	data[729] = INIT_2D[159:144];
	data[730] = INIT_2D[175:160];
	data[731] = INIT_2D[191:176];
	data[732] = INIT_2D[207:192];
	data[733] = INIT_2D[223:208];
	data[734] = INIT_2D[239:224];
	data[735] = INIT_2D[255:240];
	data[736] = INIT_2E[15:0];
	data[737] = INIT_2E[31:16];
	data[738] = INIT_2E[47:32];
	data[739] = INIT_2E[63:48];
	data[740] = INIT_2E[79:64];
	data[741] = INIT_2E[95:80];
	data[742] = INIT_2E[111:96];
	data[743] = INIT_2E[127:112];
	data[744] = INIT_2E[143:128];
	data[745] = INIT_2E[159:144];
	data[746] = INIT_2E[175:160];
	data[747] = INIT_2E[191:176];
	data[748] = INIT_2E[207:192];
	data[749] = INIT_2E[223:208];
	data[750] = INIT_2E[239:224];
	data[751] = INIT_2E[255:240];
	data[752] = INIT_2F[15:0];
	data[753] = INIT_2F[31:16];
	data[754] = INIT_2F[47:32];
	data[755] = INIT_2F[63:48];
	data[756] = INIT_2F[79:64];
	data[757] = INIT_2F[95:80];
	data[758] = INIT_2F[111:96];
	data[759] = INIT_2F[127:112];
	data[760] = INIT_2F[143:128];
	data[761] = INIT_2F[159:144];
	data[762] = INIT_2F[175:160];
	data[763] = INIT_2F[191:176];
	data[764] = INIT_2F[207:192];
	data[765] = INIT_2F[223:208];
	data[766] = INIT_2F[239:224];
	data[767] = INIT_2F[255:240];
	data[768] = INIT_30[15:0];
	data[769] = INIT_30[31:16];
	data[770] = INIT_30[47:32];
	data[771] = INIT_30[63:48];
	data[772] = INIT_30[79:64];
	data[773] = INIT_30[95:80];
	data[774] = INIT_30[111:96];
	data[775] = INIT_30[127:112];
	data[776] = INIT_30[143:128];
	data[777] = INIT_30[159:144];
	data[778] = INIT_30[175:160];
	data[779] = INIT_30[191:176];
	data[780] = INIT_30[207:192];
	data[781] = INIT_30[223:208];
	data[782] = INIT_30[239:224];
	data[783] = INIT_30[255:240];
	data[784] = INIT_31[15:0];
	data[785] = INIT_31[31:16];
	data[786] = INIT_31[47:32];
	data[787] = INIT_31[63:48];
	data[788] = INIT_31[79:64];
	data[789] = INIT_31[95:80];
	data[790] = INIT_31[111:96];
	data[791] = INIT_31[127:112];
	data[792] = INIT_31[143:128];
	data[793] = INIT_31[159:144];
	data[794] = INIT_31[175:160];
	data[795] = INIT_31[191:176];
	data[796] = INIT_31[207:192];
	data[797] = INIT_31[223:208];
	data[798] = INIT_31[239:224];
	data[799] = INIT_31[255:240];
	data[800] = INIT_32[15:0];
	data[801] = INIT_32[31:16];
	data[802] = INIT_32[47:32];
	data[803] = INIT_32[63:48];
	data[804] = INIT_32[79:64];
	data[805] = INIT_32[95:80];
	data[806] = INIT_32[111:96];
	data[807] = INIT_32[127:112];
	data[808] = INIT_32[143:128];
	data[809] = INIT_32[159:144];
	data[810] = INIT_32[175:160];
	data[811] = INIT_32[191:176];
	data[812] = INIT_32[207:192];
	data[813] = INIT_32[223:208];
	data[814] = INIT_32[239:224];
	data[815] = INIT_32[255:240];
	data[816] = INIT_33[15:0];
	data[817] = INIT_33[31:16];
	data[818] = INIT_33[47:32];
	data[819] = INIT_33[63:48];
	data[820] = INIT_33[79:64];
	data[821] = INIT_33[95:80];
	data[822] = INIT_33[111:96];
	data[823] = INIT_33[127:112];
	data[824] = INIT_33[143:128];
	data[825] = INIT_33[159:144];
	data[826] = INIT_33[175:160];
	data[827] = INIT_33[191:176];
	data[828] = INIT_33[207:192];
	data[829] = INIT_33[223:208];
	data[830] = INIT_33[239:224];
	data[831] = INIT_33[255:240];
	data[832] = INIT_34[15:0];
	data[833] = INIT_34[31:16];
	data[834] = INIT_34[47:32];
	data[835] = INIT_34[63:48];
	data[836] = INIT_34[79:64];
	data[837] = INIT_34[95:80];
	data[838] = INIT_34[111:96];
	data[839] = INIT_34[127:112];
	data[840] = INIT_34[143:128];
	data[841] = INIT_34[159:144];
	data[842] = INIT_34[175:160];
	data[843] = INIT_34[191:176];
	data[844] = INIT_34[207:192];
	data[845] = INIT_34[223:208];
	data[846] = INIT_34[239:224];
	data[847] = INIT_34[255:240];
	data[848] = INIT_35[15:0];
	data[849] = INIT_35[31:16];
	data[850] = INIT_35[47:32];
	data[851] = INIT_35[63:48];
	data[852] = INIT_35[79:64];
	data[853] = INIT_35[95:80];
	data[854] = INIT_35[111:96];
	data[855] = INIT_35[127:112];
	data[856] = INIT_35[143:128];
	data[857] = INIT_35[159:144];
	data[858] = INIT_35[175:160];
	data[859] = INIT_35[191:176];
	data[860] = INIT_35[207:192];
	data[861] = INIT_35[223:208];
	data[862] = INIT_35[239:224];
	data[863] = INIT_35[255:240];
	data[864] = INIT_36[15:0];
	data[865] = INIT_36[31:16];
	data[866] = INIT_36[47:32];
	data[867] = INIT_36[63:48];
	data[868] = INIT_36[79:64];
	data[869] = INIT_36[95:80];
	data[870] = INIT_36[111:96];
	data[871] = INIT_36[127:112];
	data[872] = INIT_36[143:128];
	data[873] = INIT_36[159:144];
	data[874] = INIT_36[175:160];
	data[875] = INIT_36[191:176];
	data[876] = INIT_36[207:192];
	data[877] = INIT_36[223:208];
	data[878] = INIT_36[239:224];
	data[879] = INIT_36[255:240];
	data[880] = INIT_37[15:0];
	data[881] = INIT_37[31:16];
	data[882] = INIT_37[47:32];
	data[883] = INIT_37[63:48];
	data[884] = INIT_37[79:64];
	data[885] = INIT_37[95:80];
	data[886] = INIT_37[111:96];
	data[887] = INIT_37[127:112];
	data[888] = INIT_37[143:128];
	data[889] = INIT_37[159:144];
	data[890] = INIT_37[175:160];
	data[891] = INIT_37[191:176];
	data[892] = INIT_37[207:192];
	data[893] = INIT_37[223:208];
	data[894] = INIT_37[239:224];
	data[895] = INIT_37[255:240];
	data[896] = INIT_38[15:0];
	data[897] = INIT_38[31:16];
	data[898] = INIT_38[47:32];
	data[899] = INIT_38[63:48];
	data[900] = INIT_38[79:64];
	data[901] = INIT_38[95:80];
	data[902] = INIT_38[111:96];
	data[903] = INIT_38[127:112];
	data[904] = INIT_38[143:128];
	data[905] = INIT_38[159:144];
	data[906] = INIT_38[175:160];
	data[907] = INIT_38[191:176];
	data[908] = INIT_38[207:192];
	data[909] = INIT_38[223:208];
	data[910] = INIT_38[239:224];
	data[911] = INIT_38[255:240];
	data[912] = INIT_39[15:0];
	data[913] = INIT_39[31:16];
	data[914] = INIT_39[47:32];
	data[915] = INIT_39[63:48];
	data[916] = INIT_39[79:64];
	data[917] = INIT_39[95:80];
	data[918] = INIT_39[111:96];
	data[919] = INIT_39[127:112];
	data[920] = INIT_39[143:128];
	data[921] = INIT_39[159:144];
	data[922] = INIT_39[175:160];
	data[923] = INIT_39[191:176];
	data[924] = INIT_39[207:192];
	data[925] = INIT_39[223:208];
	data[926] = INIT_39[239:224];
	data[927] = INIT_39[255:240];
	data[928] = INIT_3A[15:0];
	data[929] = INIT_3A[31:16];
	data[930] = INIT_3A[47:32];
	data[931] = INIT_3A[63:48];
	data[932] = INIT_3A[79:64];
	data[933] = INIT_3A[95:80];
	data[934] = INIT_3A[111:96];
	data[935] = INIT_3A[127:112];
	data[936] = INIT_3A[143:128];
	data[937] = INIT_3A[159:144];
	data[938] = INIT_3A[175:160];
	data[939] = INIT_3A[191:176];
	data[940] = INIT_3A[207:192];
	data[941] = INIT_3A[223:208];
	data[942] = INIT_3A[239:224];
	data[943] = INIT_3A[255:240];
	data[944] = INIT_3B[15:0];
	data[945] = INIT_3B[31:16];
	data[946] = INIT_3B[47:32];
	data[947] = INIT_3B[63:48];
	data[948] = INIT_3B[79:64];
	data[949] = INIT_3B[95:80];
	data[950] = INIT_3B[111:96];
	data[951] = INIT_3B[127:112];
	data[952] = INIT_3B[143:128];
	data[953] = INIT_3B[159:144];
	data[954] = INIT_3B[175:160];
	data[955] = INIT_3B[191:176];
	data[956] = INIT_3B[207:192];
	data[957] = INIT_3B[223:208];
	data[958] = INIT_3B[239:224];
	data[959] = INIT_3B[255:240];
	data[960] = INIT_3C[15:0];
	data[961] = INIT_3C[31:16];
	data[962] = INIT_3C[47:32];
	data[963] = INIT_3C[63:48];
	data[964] = INIT_3C[79:64];
	data[965] = INIT_3C[95:80];
	data[966] = INIT_3C[111:96];
	data[967] = INIT_3C[127:112];
	data[968] = INIT_3C[143:128];
	data[969] = INIT_3C[159:144];
	data[970] = INIT_3C[175:160];
	data[971] = INIT_3C[191:176];
	data[972] = INIT_3C[207:192];
	data[973] = INIT_3C[223:208];
	data[974] = INIT_3C[239:224];
	data[975] = INIT_3C[255:240];
	data[976] = INIT_3D[15:0];
	data[977] = INIT_3D[31:16];
	data[978] = INIT_3D[47:32];
	data[979] = INIT_3D[63:48];
	data[980] = INIT_3D[79:64];
	data[981] = INIT_3D[95:80];
	data[982] = INIT_3D[111:96];
	data[983] = INIT_3D[127:112];
	data[984] = INIT_3D[143:128];
	data[985] = INIT_3D[159:144];
	data[986] = INIT_3D[175:160];
	data[987] = INIT_3D[191:176];
	data[988] = INIT_3D[207:192];
	data[989] = INIT_3D[223:208];
	data[990] = INIT_3D[239:224];
	data[991] = INIT_3D[255:240];
	data[992] = INIT_3E[15:0];
	data[993] = INIT_3E[31:16];
	data[994] = INIT_3E[47:32];
	data[995] = INIT_3E[63:48];
	data[996] = INIT_3E[79:64];
	data[997] = INIT_3E[95:80];
	data[998] = INIT_3E[111:96];
	data[999] = INIT_3E[127:112];
	data[1000] = INIT_3E[143:128];
	data[1001] = INIT_3E[159:144];
	data[1002] = INIT_3E[175:160];
	data[1003] = INIT_3E[191:176];
	data[1004] = INIT_3E[207:192];
	data[1005] = INIT_3E[223:208];
	data[1006] = INIT_3E[239:224];
	data[1007] = INIT_3E[255:240];
	data[1008] = INIT_3F[15:0];
	data[1009] = INIT_3F[31:16];
	data[1010] = INIT_3F[47:32];
	data[1011] = INIT_3F[63:48];
	data[1012] = INIT_3F[79:64];
	data[1013] = INIT_3F[95:80];
	data[1014] = INIT_3F[111:96];
	data[1015] = INIT_3F[127:112];
	data[1016] = INIT_3F[143:128];
	data[1017] = INIT_3F[159:144];
	data[1018] = INIT_3F[175:160];
	data[1019] = INIT_3F[191:176];
	data[1020] = INIT_3F[207:192];
	data[1021] = INIT_3F[223:208];
	data[1022] = INIT_3F[239:224];
	data[1023] = INIT_3F[255:240];
	parity[0] = INITP_00[1:0];
	parity[1] = INITP_00[3:2];
	parity[2] = INITP_00[5:4];
	parity[3] = INITP_00[7:6];
	parity[4] = INITP_00[9:8];
	parity[5] = INITP_00[11:10];
	parity[6] = INITP_00[13:12];
	parity[7] = INITP_00[15:14];
	parity[8] = INITP_00[17:16];
	parity[9] = INITP_00[19:18];
	parity[10] = INITP_00[21:20];
	parity[11] = INITP_00[23:22];
	parity[12] = INITP_00[25:24];
	parity[13] = INITP_00[27:26];
	parity[14] = INITP_00[29:28];
	parity[15] = INITP_00[31:30];
	parity[16] = INITP_00[33:32];
	parity[17] = INITP_00[35:34];
	parity[18] = INITP_00[37:36];
	parity[19] = INITP_00[39:38];
	parity[20] = INITP_00[41:40];
	parity[21] = INITP_00[43:42];
	parity[22] = INITP_00[45:44];
	parity[23] = INITP_00[47:46];
	parity[24] = INITP_00[49:48];
	parity[25] = INITP_00[51:50];
	parity[26] = INITP_00[53:52];
	parity[27] = INITP_00[55:54];
	parity[28] = INITP_00[57:56];
	parity[29] = INITP_00[59:58];
	parity[30] = INITP_00[61:60];
	parity[31] = INITP_00[63:62];
	parity[32] = INITP_00[65:64];
	parity[33] = INITP_00[67:66];
	parity[34] = INITP_00[69:68];
	parity[35] = INITP_00[71:70];
	parity[36] = INITP_00[73:72];
	parity[37] = INITP_00[75:74];
	parity[38] = INITP_00[77:76];
	parity[39] = INITP_00[79:78];
	parity[40] = INITP_00[81:80];
	parity[41] = INITP_00[83:82];
	parity[42] = INITP_00[85:84];
	parity[43] = INITP_00[87:86];
	parity[44] = INITP_00[89:88];
	parity[45] = INITP_00[91:90];
	parity[46] = INITP_00[93:92];
	parity[47] = INITP_00[95:94];
	parity[48] = INITP_00[97:96];
	parity[49] = INITP_00[99:98];
	parity[50] = INITP_00[101:100];
	parity[51] = INITP_00[103:102];
	parity[52] = INITP_00[105:104];
	parity[53] = INITP_00[107:106];
	parity[54] = INITP_00[109:108];
	parity[55] = INITP_00[111:110];
	parity[56] = INITP_00[113:112];
	parity[57] = INITP_00[115:114];
	parity[58] = INITP_00[117:116];
	parity[59] = INITP_00[119:118];
	parity[60] = INITP_00[121:120];
	parity[61] = INITP_00[123:122];
	parity[62] = INITP_00[125:124];
	parity[63] = INITP_00[127:126];
	parity[64] = INITP_00[129:128];
	parity[65] = INITP_00[131:130];
	parity[66] = INITP_00[133:132];
	parity[67] = INITP_00[135:134];
	parity[68] = INITP_00[137:136];
	parity[69] = INITP_00[139:138];
	parity[70] = INITP_00[141:140];
	parity[71] = INITP_00[143:142];
	parity[72] = INITP_00[145:144];
	parity[73] = INITP_00[147:146];
	parity[74] = INITP_00[149:148];
	parity[75] = INITP_00[151:150];
	parity[76] = INITP_00[153:152];
	parity[77] = INITP_00[155:154];
	parity[78] = INITP_00[157:156];
	parity[79] = INITP_00[159:158];
	parity[80] = INITP_00[161:160];
	parity[81] = INITP_00[163:162];
	parity[82] = INITP_00[165:164];
	parity[83] = INITP_00[167:166];
	parity[84] = INITP_00[169:168];
	parity[85] = INITP_00[171:170];
	parity[86] = INITP_00[173:172];
	parity[87] = INITP_00[175:174];
	parity[88] = INITP_00[177:176];
	parity[89] = INITP_00[179:178];
	parity[90] = INITP_00[181:180];
	parity[91] = INITP_00[183:182];
	parity[92] = INITP_00[185:184];
	parity[93] = INITP_00[187:186];
	parity[94] = INITP_00[189:188];
	parity[95] = INITP_00[191:190];
	parity[96] = INITP_00[193:192];
	parity[97] = INITP_00[195:194];
	parity[98] = INITP_00[197:196];
	parity[99] = INITP_00[199:198];
	parity[100] = INITP_00[201:200];
	parity[101] = INITP_00[203:202];
	parity[102] = INITP_00[205:204];
	parity[103] = INITP_00[207:206];
	parity[104] = INITP_00[209:208];
	parity[105] = INITP_00[211:210];
	parity[106] = INITP_00[213:212];
	parity[107] = INITP_00[215:214];
	parity[108] = INITP_00[217:216];
	parity[109] = INITP_00[219:218];
	parity[110] = INITP_00[221:220];
	parity[111] = INITP_00[223:222];
	parity[112] = INITP_00[225:224];
	parity[113] = INITP_00[227:226];
	parity[114] = INITP_00[229:228];
	parity[115] = INITP_00[231:230];
	parity[116] = INITP_00[233:232];
	parity[117] = INITP_00[235:234];
	parity[118] = INITP_00[237:236];
	parity[119] = INITP_00[239:238];
	parity[120] = INITP_00[241:240];
	parity[121] = INITP_00[243:242];
	parity[122] = INITP_00[245:244];
	parity[123] = INITP_00[247:246];
	parity[124] = INITP_00[249:248];
	parity[125] = INITP_00[251:250];
	parity[126] = INITP_00[253:252];
	parity[127] = INITP_00[255:254];
	parity[128] = INITP_01[1:0];
	parity[129] = INITP_01[3:2];
	parity[130] = INITP_01[5:4];
	parity[131] = INITP_01[7:6];
	parity[132] = INITP_01[9:8];
	parity[133] = INITP_01[11:10];
	parity[134] = INITP_01[13:12];
	parity[135] = INITP_01[15:14];
	parity[136] = INITP_01[17:16];
	parity[137] = INITP_01[19:18];
	parity[138] = INITP_01[21:20];
	parity[139] = INITP_01[23:22];
	parity[140] = INITP_01[25:24];
	parity[141] = INITP_01[27:26];
	parity[142] = INITP_01[29:28];
	parity[143] = INITP_01[31:30];
	parity[144] = INITP_01[33:32];
	parity[145] = INITP_01[35:34];
	parity[146] = INITP_01[37:36];
	parity[147] = INITP_01[39:38];
	parity[148] = INITP_01[41:40];
	parity[149] = INITP_01[43:42];
	parity[150] = INITP_01[45:44];
	parity[151] = INITP_01[47:46];
	parity[152] = INITP_01[49:48];
	parity[153] = INITP_01[51:50];
	parity[154] = INITP_01[53:52];
	parity[155] = INITP_01[55:54];
	parity[156] = INITP_01[57:56];
	parity[157] = INITP_01[59:58];
	parity[158] = INITP_01[61:60];
	parity[159] = INITP_01[63:62];
	parity[160] = INITP_01[65:64];
	parity[161] = INITP_01[67:66];
	parity[162] = INITP_01[69:68];
	parity[163] = INITP_01[71:70];
	parity[164] = INITP_01[73:72];
	parity[165] = INITP_01[75:74];
	parity[166] = INITP_01[77:76];
	parity[167] = INITP_01[79:78];
	parity[168] = INITP_01[81:80];
	parity[169] = INITP_01[83:82];
	parity[170] = INITP_01[85:84];
	parity[171] = INITP_01[87:86];
	parity[172] = INITP_01[89:88];
	parity[173] = INITP_01[91:90];
	parity[174] = INITP_01[93:92];
	parity[175] = INITP_01[95:94];
	parity[176] = INITP_01[97:96];
	parity[177] = INITP_01[99:98];
	parity[178] = INITP_01[101:100];
	parity[179] = INITP_01[103:102];
	parity[180] = INITP_01[105:104];
	parity[181] = INITP_01[107:106];
	parity[182] = INITP_01[109:108];
	parity[183] = INITP_01[111:110];
	parity[184] = INITP_01[113:112];
	parity[185] = INITP_01[115:114];
	parity[186] = INITP_01[117:116];
	parity[187] = INITP_01[119:118];
	parity[188] = INITP_01[121:120];
	parity[189] = INITP_01[123:122];
	parity[190] = INITP_01[125:124];
	parity[191] = INITP_01[127:126];
	parity[192] = INITP_01[129:128];
	parity[193] = INITP_01[131:130];
	parity[194] = INITP_01[133:132];
	parity[195] = INITP_01[135:134];
	parity[196] = INITP_01[137:136];
	parity[197] = INITP_01[139:138];
	parity[198] = INITP_01[141:140];
	parity[199] = INITP_01[143:142];
	parity[200] = INITP_01[145:144];
	parity[201] = INITP_01[147:146];
	parity[202] = INITP_01[149:148];
	parity[203] = INITP_01[151:150];
	parity[204] = INITP_01[153:152];
	parity[205] = INITP_01[155:154];
	parity[206] = INITP_01[157:156];
	parity[207] = INITP_01[159:158];
	parity[208] = INITP_01[161:160];
	parity[209] = INITP_01[163:162];
	parity[210] = INITP_01[165:164];
	parity[211] = INITP_01[167:166];
	parity[212] = INITP_01[169:168];
	parity[213] = INITP_01[171:170];
	parity[214] = INITP_01[173:172];
	parity[215] = INITP_01[175:174];
	parity[216] = INITP_01[177:176];
	parity[217] = INITP_01[179:178];
	parity[218] = INITP_01[181:180];
	parity[219] = INITP_01[183:182];
	parity[220] = INITP_01[185:184];
	parity[221] = INITP_01[187:186];
	parity[222] = INITP_01[189:188];
	parity[223] = INITP_01[191:190];
	parity[224] = INITP_01[193:192];
	parity[225] = INITP_01[195:194];
	parity[226] = INITP_01[197:196];
	parity[227] = INITP_01[199:198];
	parity[228] = INITP_01[201:200];
	parity[229] = INITP_01[203:202];
	parity[230] = INITP_01[205:204];
	parity[231] = INITP_01[207:206];
	parity[232] = INITP_01[209:208];
	parity[233] = INITP_01[211:210];
	parity[234] = INITP_01[213:212];
	parity[235] = INITP_01[215:214];
	parity[236] = INITP_01[217:216];
	parity[237] = INITP_01[219:218];
	parity[238] = INITP_01[221:220];
	parity[239] = INITP_01[223:222];
	parity[240] = INITP_01[225:224];
	parity[241] = INITP_01[227:226];
	parity[242] = INITP_01[229:228];
	parity[243] = INITP_01[231:230];
	parity[244] = INITP_01[233:232];
	parity[245] = INITP_01[235:234];
	parity[246] = INITP_01[237:236];
	parity[247] = INITP_01[239:238];
	parity[248] = INITP_01[241:240];
	parity[249] = INITP_01[243:242];
	parity[250] = INITP_01[245:244];
	parity[251] = INITP_01[247:246];
	parity[252] = INITP_01[249:248];
	parity[253] = INITP_01[251:250];
	parity[254] = INITP_01[253:252];
	parity[255] = INITP_01[255:254];
	parity[256] = INITP_02[1:0];
	parity[257] = INITP_02[3:2];
	parity[258] = INITP_02[5:4];
	parity[259] = INITP_02[7:6];
	parity[260] = INITP_02[9:8];
	parity[261] = INITP_02[11:10];
	parity[262] = INITP_02[13:12];
	parity[263] = INITP_02[15:14];
	parity[264] = INITP_02[17:16];
	parity[265] = INITP_02[19:18];
	parity[266] = INITP_02[21:20];
	parity[267] = INITP_02[23:22];
	parity[268] = INITP_02[25:24];
	parity[269] = INITP_02[27:26];
	parity[270] = INITP_02[29:28];
	parity[271] = INITP_02[31:30];
	parity[272] = INITP_02[33:32];
	parity[273] = INITP_02[35:34];
	parity[274] = INITP_02[37:36];
	parity[275] = INITP_02[39:38];
	parity[276] = INITP_02[41:40];
	parity[277] = INITP_02[43:42];
	parity[278] = INITP_02[45:44];
	parity[279] = INITP_02[47:46];
	parity[280] = INITP_02[49:48];
	parity[281] = INITP_02[51:50];
	parity[282] = INITP_02[53:52];
	parity[283] = INITP_02[55:54];
	parity[284] = INITP_02[57:56];
	parity[285] = INITP_02[59:58];
	parity[286] = INITP_02[61:60];
	parity[287] = INITP_02[63:62];
	parity[288] = INITP_02[65:64];
	parity[289] = INITP_02[67:66];
	parity[290] = INITP_02[69:68];
	parity[291] = INITP_02[71:70];
	parity[292] = INITP_02[73:72];
	parity[293] = INITP_02[75:74];
	parity[294] = INITP_02[77:76];
	parity[295] = INITP_02[79:78];
	parity[296] = INITP_02[81:80];
	parity[297] = INITP_02[83:82];
	parity[298] = INITP_02[85:84];
	parity[299] = INITP_02[87:86];
	parity[300] = INITP_02[89:88];
	parity[301] = INITP_02[91:90];
	parity[302] = INITP_02[93:92];
	parity[303] = INITP_02[95:94];
	parity[304] = INITP_02[97:96];
	parity[305] = INITP_02[99:98];
	parity[306] = INITP_02[101:100];
	parity[307] = INITP_02[103:102];
	parity[308] = INITP_02[105:104];
	parity[309] = INITP_02[107:106];
	parity[310] = INITP_02[109:108];
	parity[311] = INITP_02[111:110];
	parity[312] = INITP_02[113:112];
	parity[313] = INITP_02[115:114];
	parity[314] = INITP_02[117:116];
	parity[315] = INITP_02[119:118];
	parity[316] = INITP_02[121:120];
	parity[317] = INITP_02[123:122];
	parity[318] = INITP_02[125:124];
	parity[319] = INITP_02[127:126];
	parity[320] = INITP_02[129:128];
	parity[321] = INITP_02[131:130];
	parity[322] = INITP_02[133:132];
	parity[323] = INITP_02[135:134];
	parity[324] = INITP_02[137:136];
	parity[325] = INITP_02[139:138];
	parity[326] = INITP_02[141:140];
	parity[327] = INITP_02[143:142];
	parity[328] = INITP_02[145:144];
	parity[329] = INITP_02[147:146];
	parity[330] = INITP_02[149:148];
	parity[331] = INITP_02[151:150];
	parity[332] = INITP_02[153:152];
	parity[333] = INITP_02[155:154];
	parity[334] = INITP_02[157:156];
	parity[335] = INITP_02[159:158];
	parity[336] = INITP_02[161:160];
	parity[337] = INITP_02[163:162];
	parity[338] = INITP_02[165:164];
	parity[339] = INITP_02[167:166];
	parity[340] = INITP_02[169:168];
	parity[341] = INITP_02[171:170];
	parity[342] = INITP_02[173:172];
	parity[343] = INITP_02[175:174];
	parity[344] = INITP_02[177:176];
	parity[345] = INITP_02[179:178];
	parity[346] = INITP_02[181:180];
	parity[347] = INITP_02[183:182];
	parity[348] = INITP_02[185:184];
	parity[349] = INITP_02[187:186];
	parity[350] = INITP_02[189:188];
	parity[351] = INITP_02[191:190];
	parity[352] = INITP_02[193:192];
	parity[353] = INITP_02[195:194];
	parity[354] = INITP_02[197:196];
	parity[355] = INITP_02[199:198];
	parity[356] = INITP_02[201:200];
	parity[357] = INITP_02[203:202];
	parity[358] = INITP_02[205:204];
	parity[359] = INITP_02[207:206];
	parity[360] = INITP_02[209:208];
	parity[361] = INITP_02[211:210];
	parity[362] = INITP_02[213:212];
	parity[363] = INITP_02[215:214];
	parity[364] = INITP_02[217:216];
	parity[365] = INITP_02[219:218];
	parity[366] = INITP_02[221:220];
	parity[367] = INITP_02[223:222];
	parity[368] = INITP_02[225:224];
	parity[369] = INITP_02[227:226];
	parity[370] = INITP_02[229:228];
	parity[371] = INITP_02[231:230];
	parity[372] = INITP_02[233:232];
	parity[373] = INITP_02[235:234];
	parity[374] = INITP_02[237:236];
	parity[375] = INITP_02[239:238];
	parity[376] = INITP_02[241:240];
	parity[377] = INITP_02[243:242];
	parity[378] = INITP_02[245:244];
	parity[379] = INITP_02[247:246];
	parity[380] = INITP_02[249:248];
	parity[381] = INITP_02[251:250];
	parity[382] = INITP_02[253:252];
	parity[383] = INITP_02[255:254];
	parity[384] = INITP_03[1:0];
	parity[385] = INITP_03[3:2];
	parity[386] = INITP_03[5:4];
	parity[387] = INITP_03[7:6];
	parity[388] = INITP_03[9:8];
	parity[389] = INITP_03[11:10];
	parity[390] = INITP_03[13:12];
	parity[391] = INITP_03[15:14];
	parity[392] = INITP_03[17:16];
	parity[393] = INITP_03[19:18];
	parity[394] = INITP_03[21:20];
	parity[395] = INITP_03[23:22];
	parity[396] = INITP_03[25:24];
	parity[397] = INITP_03[27:26];
	parity[398] = INITP_03[29:28];
	parity[399] = INITP_03[31:30];
	parity[400] = INITP_03[33:32];
	parity[401] = INITP_03[35:34];
	parity[402] = INITP_03[37:36];
	parity[403] = INITP_03[39:38];
	parity[404] = INITP_03[41:40];
	parity[405] = INITP_03[43:42];
	parity[406] = INITP_03[45:44];
	parity[407] = INITP_03[47:46];
	parity[408] = INITP_03[49:48];
	parity[409] = INITP_03[51:50];
	parity[410] = INITP_03[53:52];
	parity[411] = INITP_03[55:54];
	parity[412] = INITP_03[57:56];
	parity[413] = INITP_03[59:58];
	parity[414] = INITP_03[61:60];
	parity[415] = INITP_03[63:62];
	parity[416] = INITP_03[65:64];
	parity[417] = INITP_03[67:66];
	parity[418] = INITP_03[69:68];
	parity[419] = INITP_03[71:70];
	parity[420] = INITP_03[73:72];
	parity[421] = INITP_03[75:74];
	parity[422] = INITP_03[77:76];
	parity[423] = INITP_03[79:78];
	parity[424] = INITP_03[81:80];
	parity[425] = INITP_03[83:82];
	parity[426] = INITP_03[85:84];
	parity[427] = INITP_03[87:86];
	parity[428] = INITP_03[89:88];
	parity[429] = INITP_03[91:90];
	parity[430] = INITP_03[93:92];
	parity[431] = INITP_03[95:94];
	parity[432] = INITP_03[97:96];
	parity[433] = INITP_03[99:98];
	parity[434] = INITP_03[101:100];
	parity[435] = INITP_03[103:102];
	parity[436] = INITP_03[105:104];
	parity[437] = INITP_03[107:106];
	parity[438] = INITP_03[109:108];
	parity[439] = INITP_03[111:110];
	parity[440] = INITP_03[113:112];
	parity[441] = INITP_03[115:114];
	parity[442] = INITP_03[117:116];
	parity[443] = INITP_03[119:118];
	parity[444] = INITP_03[121:120];
	parity[445] = INITP_03[123:122];
	parity[446] = INITP_03[125:124];
	parity[447] = INITP_03[127:126];
	parity[448] = INITP_03[129:128];
	parity[449] = INITP_03[131:130];
	parity[450] = INITP_03[133:132];
	parity[451] = INITP_03[135:134];
	parity[452] = INITP_03[137:136];
	parity[453] = INITP_03[139:138];
	parity[454] = INITP_03[141:140];
	parity[455] = INITP_03[143:142];
	parity[456] = INITP_03[145:144];
	parity[457] = INITP_03[147:146];
	parity[458] = INITP_03[149:148];
	parity[459] = INITP_03[151:150];
	parity[460] = INITP_03[153:152];
	parity[461] = INITP_03[155:154];
	parity[462] = INITP_03[157:156];
	parity[463] = INITP_03[159:158];
	parity[464] = INITP_03[161:160];
	parity[465] = INITP_03[163:162];
	parity[466] = INITP_03[165:164];
	parity[467] = INITP_03[167:166];
	parity[468] = INITP_03[169:168];
	parity[469] = INITP_03[171:170];
	parity[470] = INITP_03[173:172];
	parity[471] = INITP_03[175:174];
	parity[472] = INITP_03[177:176];
	parity[473] = INITP_03[179:178];
	parity[474] = INITP_03[181:180];
	parity[475] = INITP_03[183:182];
	parity[476] = INITP_03[185:184];
	parity[477] = INITP_03[187:186];
	parity[478] = INITP_03[189:188];
	parity[479] = INITP_03[191:190];
	parity[480] = INITP_03[193:192];
	parity[481] = INITP_03[195:194];
	parity[482] = INITP_03[197:196];
	parity[483] = INITP_03[199:198];
	parity[484] = INITP_03[201:200];
	parity[485] = INITP_03[203:202];
	parity[486] = INITP_03[205:204];
	parity[487] = INITP_03[207:206];
	parity[488] = INITP_03[209:208];
	parity[489] = INITP_03[211:210];
	parity[490] = INITP_03[213:212];
	parity[491] = INITP_03[215:214];
	parity[492] = INITP_03[217:216];
	parity[493] = INITP_03[219:218];
	parity[494] = INITP_03[221:220];
	parity[495] = INITP_03[223:222];
	parity[496] = INITP_03[225:224];
	parity[497] = INITP_03[227:226];
	parity[498] = INITP_03[229:228];
	parity[499] = INITP_03[231:230];
	parity[500] = INITP_03[233:232];
	parity[501] = INITP_03[235:234];
	parity[502] = INITP_03[237:236];
	parity[503] = INITP_03[239:238];
	parity[504] = INITP_03[241:240];
	parity[505] = INITP_03[243:242];
	parity[506] = INITP_03[245:244];
	parity[507] = INITP_03[247:246];
	parity[508] = INITP_03[249:248];
	parity[509] = INITP_03[251:250];
	parity[510] = INITP_03[253:252];
	parity[511] = INITP_03[255:254];
	parity[512] = INITP_04[1:0];
	parity[513] = INITP_04[3:2];
	parity[514] = INITP_04[5:4];
	parity[515] = INITP_04[7:6];
	parity[516] = INITP_04[9:8];
	parity[517] = INITP_04[11:10];
	parity[518] = INITP_04[13:12];
	parity[519] = INITP_04[15:14];
	parity[520] = INITP_04[17:16];
	parity[521] = INITP_04[19:18];
	parity[522] = INITP_04[21:20];
	parity[523] = INITP_04[23:22];
	parity[524] = INITP_04[25:24];
	parity[525] = INITP_04[27:26];
	parity[526] = INITP_04[29:28];
	parity[527] = INITP_04[31:30];
	parity[528] = INITP_04[33:32];
	parity[529] = INITP_04[35:34];
	parity[530] = INITP_04[37:36];
	parity[531] = INITP_04[39:38];
	parity[532] = INITP_04[41:40];
	parity[533] = INITP_04[43:42];
	parity[534] = INITP_04[45:44];
	parity[535] = INITP_04[47:46];
	parity[536] = INITP_04[49:48];
	parity[537] = INITP_04[51:50];
	parity[538] = INITP_04[53:52];
	parity[539] = INITP_04[55:54];
	parity[540] = INITP_04[57:56];
	parity[541] = INITP_04[59:58];
	parity[542] = INITP_04[61:60];
	parity[543] = INITP_04[63:62];
	parity[544] = INITP_04[65:64];
	parity[545] = INITP_04[67:66];
	parity[546] = INITP_04[69:68];
	parity[547] = INITP_04[71:70];
	parity[548] = INITP_04[73:72];
	parity[549] = INITP_04[75:74];
	parity[550] = INITP_04[77:76];
	parity[551] = INITP_04[79:78];
	parity[552] = INITP_04[81:80];
	parity[553] = INITP_04[83:82];
	parity[554] = INITP_04[85:84];
	parity[555] = INITP_04[87:86];
	parity[556] = INITP_04[89:88];
	parity[557] = INITP_04[91:90];
	parity[558] = INITP_04[93:92];
	parity[559] = INITP_04[95:94];
	parity[560] = INITP_04[97:96];
	parity[561] = INITP_04[99:98];
	parity[562] = INITP_04[101:100];
	parity[563] = INITP_04[103:102];
	parity[564] = INITP_04[105:104];
	parity[565] = INITP_04[107:106];
	parity[566] = INITP_04[109:108];
	parity[567] = INITP_04[111:110];
	parity[568] = INITP_04[113:112];
	parity[569] = INITP_04[115:114];
	parity[570] = INITP_04[117:116];
	parity[571] = INITP_04[119:118];
	parity[572] = INITP_04[121:120];
	parity[573] = INITP_04[123:122];
	parity[574] = INITP_04[125:124];
	parity[575] = INITP_04[127:126];
	parity[576] = INITP_04[129:128];
	parity[577] = INITP_04[131:130];
	parity[578] = INITP_04[133:132];
	parity[579] = INITP_04[135:134];
	parity[580] = INITP_04[137:136];
	parity[581] = INITP_04[139:138];
	parity[582] = INITP_04[141:140];
	parity[583] = INITP_04[143:142];
	parity[584] = INITP_04[145:144];
	parity[585] = INITP_04[147:146];
	parity[586] = INITP_04[149:148];
	parity[587] = INITP_04[151:150];
	parity[588] = INITP_04[153:152];
	parity[589] = INITP_04[155:154];
	parity[590] = INITP_04[157:156];
	parity[591] = INITP_04[159:158];
	parity[592] = INITP_04[161:160];
	parity[593] = INITP_04[163:162];
	parity[594] = INITP_04[165:164];
	parity[595] = INITP_04[167:166];
	parity[596] = INITP_04[169:168];
	parity[597] = INITP_04[171:170];
	parity[598] = INITP_04[173:172];
	parity[599] = INITP_04[175:174];
	parity[600] = INITP_04[177:176];
	parity[601] = INITP_04[179:178];
	parity[602] = INITP_04[181:180];
	parity[603] = INITP_04[183:182];
	parity[604] = INITP_04[185:184];
	parity[605] = INITP_04[187:186];
	parity[606] = INITP_04[189:188];
	parity[607] = INITP_04[191:190];
	parity[608] = INITP_04[193:192];
	parity[609] = INITP_04[195:194];
	parity[610] = INITP_04[197:196];
	parity[611] = INITP_04[199:198];
	parity[612] = INITP_04[201:200];
	parity[613] = INITP_04[203:202];
	parity[614] = INITP_04[205:204];
	parity[615] = INITP_04[207:206];
	parity[616] = INITP_04[209:208];
	parity[617] = INITP_04[211:210];
	parity[618] = INITP_04[213:212];
	parity[619] = INITP_04[215:214];
	parity[620] = INITP_04[217:216];
	parity[621] = INITP_04[219:218];
	parity[622] = INITP_04[221:220];
	parity[623] = INITP_04[223:222];
	parity[624] = INITP_04[225:224];
	parity[625] = INITP_04[227:226];
	parity[626] = INITP_04[229:228];
	parity[627] = INITP_04[231:230];
	parity[628] = INITP_04[233:232];
	parity[629] = INITP_04[235:234];
	parity[630] = INITP_04[237:236];
	parity[631] = INITP_04[239:238];
	parity[632] = INITP_04[241:240];
	parity[633] = INITP_04[243:242];
	parity[634] = INITP_04[245:244];
	parity[635] = INITP_04[247:246];
	parity[636] = INITP_04[249:248];
	parity[637] = INITP_04[251:250];
	parity[638] = INITP_04[253:252];
	parity[639] = INITP_04[255:254];
	parity[640] = INITP_05[1:0];
	parity[641] = INITP_05[3:2];
	parity[642] = INITP_05[5:4];
	parity[643] = INITP_05[7:6];
	parity[644] = INITP_05[9:8];
	parity[645] = INITP_05[11:10];
	parity[646] = INITP_05[13:12];
	parity[647] = INITP_05[15:14];
	parity[648] = INITP_05[17:16];
	parity[649] = INITP_05[19:18];
	parity[650] = INITP_05[21:20];
	parity[651] = INITP_05[23:22];
	parity[652] = INITP_05[25:24];
	parity[653] = INITP_05[27:26];
	parity[654] = INITP_05[29:28];
	parity[655] = INITP_05[31:30];
	parity[656] = INITP_05[33:32];
	parity[657] = INITP_05[35:34];
	parity[658] = INITP_05[37:36];
	parity[659] = INITP_05[39:38];
	parity[660] = INITP_05[41:40];
	parity[661] = INITP_05[43:42];
	parity[662] = INITP_05[45:44];
	parity[663] = INITP_05[47:46];
	parity[664] = INITP_05[49:48];
	parity[665] = INITP_05[51:50];
	parity[666] = INITP_05[53:52];
	parity[667] = INITP_05[55:54];
	parity[668] = INITP_05[57:56];
	parity[669] = INITP_05[59:58];
	parity[670] = INITP_05[61:60];
	parity[671] = INITP_05[63:62];
	parity[672] = INITP_05[65:64];
	parity[673] = INITP_05[67:66];
	parity[674] = INITP_05[69:68];
	parity[675] = INITP_05[71:70];
	parity[676] = INITP_05[73:72];
	parity[677] = INITP_05[75:74];
	parity[678] = INITP_05[77:76];
	parity[679] = INITP_05[79:78];
	parity[680] = INITP_05[81:80];
	parity[681] = INITP_05[83:82];
	parity[682] = INITP_05[85:84];
	parity[683] = INITP_05[87:86];
	parity[684] = INITP_05[89:88];
	parity[685] = INITP_05[91:90];
	parity[686] = INITP_05[93:92];
	parity[687] = INITP_05[95:94];
	parity[688] = INITP_05[97:96];
	parity[689] = INITP_05[99:98];
	parity[690] = INITP_05[101:100];
	parity[691] = INITP_05[103:102];
	parity[692] = INITP_05[105:104];
	parity[693] = INITP_05[107:106];
	parity[694] = INITP_05[109:108];
	parity[695] = INITP_05[111:110];
	parity[696] = INITP_05[113:112];
	parity[697] = INITP_05[115:114];
	parity[698] = INITP_05[117:116];
	parity[699] = INITP_05[119:118];
	parity[700] = INITP_05[121:120];
	parity[701] = INITP_05[123:122];
	parity[702] = INITP_05[125:124];
	parity[703] = INITP_05[127:126];
	parity[704] = INITP_05[129:128];
	parity[705] = INITP_05[131:130];
	parity[706] = INITP_05[133:132];
	parity[707] = INITP_05[135:134];
	parity[708] = INITP_05[137:136];
	parity[709] = INITP_05[139:138];
	parity[710] = INITP_05[141:140];
	parity[711] = INITP_05[143:142];
	parity[712] = INITP_05[145:144];
	parity[713] = INITP_05[147:146];
	parity[714] = INITP_05[149:148];
	parity[715] = INITP_05[151:150];
	parity[716] = INITP_05[153:152];
	parity[717] = INITP_05[155:154];
	parity[718] = INITP_05[157:156];
	parity[719] = INITP_05[159:158];
	parity[720] = INITP_05[161:160];
	parity[721] = INITP_05[163:162];
	parity[722] = INITP_05[165:164];
	parity[723] = INITP_05[167:166];
	parity[724] = INITP_05[169:168];
	parity[725] = INITP_05[171:170];
	parity[726] = INITP_05[173:172];
	parity[727] = INITP_05[175:174];
	parity[728] = INITP_05[177:176];
	parity[729] = INITP_05[179:178];
	parity[730] = INITP_05[181:180];
	parity[731] = INITP_05[183:182];
	parity[732] = INITP_05[185:184];
	parity[733] = INITP_05[187:186];
	parity[734] = INITP_05[189:188];
	parity[735] = INITP_05[191:190];
	parity[736] = INITP_05[193:192];
	parity[737] = INITP_05[195:194];
	parity[738] = INITP_05[197:196];
	parity[739] = INITP_05[199:198];
	parity[740] = INITP_05[201:200];
	parity[741] = INITP_05[203:202];
	parity[742] = INITP_05[205:204];
	parity[743] = INITP_05[207:206];
	parity[744] = INITP_05[209:208];
	parity[745] = INITP_05[211:210];
	parity[746] = INITP_05[213:212];
	parity[747] = INITP_05[215:214];
	parity[748] = INITP_05[217:216];
	parity[749] = INITP_05[219:218];
	parity[750] = INITP_05[221:220];
	parity[751] = INITP_05[223:222];
	parity[752] = INITP_05[225:224];
	parity[753] = INITP_05[227:226];
	parity[754] = INITP_05[229:228];
	parity[755] = INITP_05[231:230];
	parity[756] = INITP_05[233:232];
	parity[757] = INITP_05[235:234];
	parity[758] = INITP_05[237:236];
	parity[759] = INITP_05[239:238];
	parity[760] = INITP_05[241:240];
	parity[761] = INITP_05[243:242];
	parity[762] = INITP_05[245:244];
	parity[763] = INITP_05[247:246];
	parity[764] = INITP_05[249:248];
	parity[765] = INITP_05[251:250];
	parity[766] = INITP_05[253:252];
	parity[767] = INITP_05[255:254];
	parity[768] = INITP_06[1:0];
	parity[769] = INITP_06[3:2];
	parity[770] = INITP_06[5:4];
	parity[771] = INITP_06[7:6];
	parity[772] = INITP_06[9:8];
	parity[773] = INITP_06[11:10];
	parity[774] = INITP_06[13:12];
	parity[775] = INITP_06[15:14];
	parity[776] = INITP_06[17:16];
	parity[777] = INITP_06[19:18];
	parity[778] = INITP_06[21:20];
	parity[779] = INITP_06[23:22];
	parity[780] = INITP_06[25:24];
	parity[781] = INITP_06[27:26];
	parity[782] = INITP_06[29:28];
	parity[783] = INITP_06[31:30];
	parity[784] = INITP_06[33:32];
	parity[785] = INITP_06[35:34];
	parity[786] = INITP_06[37:36];
	parity[787] = INITP_06[39:38];
	parity[788] = INITP_06[41:40];
	parity[789] = INITP_06[43:42];
	parity[790] = INITP_06[45:44];
	parity[791] = INITP_06[47:46];
	parity[792] = INITP_06[49:48];
	parity[793] = INITP_06[51:50];
	parity[794] = INITP_06[53:52];
	parity[795] = INITP_06[55:54];
	parity[796] = INITP_06[57:56];
	parity[797] = INITP_06[59:58];
	parity[798] = INITP_06[61:60];
	parity[799] = INITP_06[63:62];
	parity[800] = INITP_06[65:64];
	parity[801] = INITP_06[67:66];
	parity[802] = INITP_06[69:68];
	parity[803] = INITP_06[71:70];
	parity[804] = INITP_06[73:72];
	parity[805] = INITP_06[75:74];
	parity[806] = INITP_06[77:76];
	parity[807] = INITP_06[79:78];
	parity[808] = INITP_06[81:80];
	parity[809] = INITP_06[83:82];
	parity[810] = INITP_06[85:84];
	parity[811] = INITP_06[87:86];
	parity[812] = INITP_06[89:88];
	parity[813] = INITP_06[91:90];
	parity[814] = INITP_06[93:92];
	parity[815] = INITP_06[95:94];
	parity[816] = INITP_06[97:96];
	parity[817] = INITP_06[99:98];
	parity[818] = INITP_06[101:100];
	parity[819] = INITP_06[103:102];
	parity[820] = INITP_06[105:104];
	parity[821] = INITP_06[107:106];
	parity[822] = INITP_06[109:108];
	parity[823] = INITP_06[111:110];
	parity[824] = INITP_06[113:112];
	parity[825] = INITP_06[115:114];
	parity[826] = INITP_06[117:116];
	parity[827] = INITP_06[119:118];
	parity[828] = INITP_06[121:120];
	parity[829] = INITP_06[123:122];
	parity[830] = INITP_06[125:124];
	parity[831] = INITP_06[127:126];
	parity[832] = INITP_06[129:128];
	parity[833] = INITP_06[131:130];
	parity[834] = INITP_06[133:132];
	parity[835] = INITP_06[135:134];
	parity[836] = INITP_06[137:136];
	parity[837] = INITP_06[139:138];
	parity[838] = INITP_06[141:140];
	parity[839] = INITP_06[143:142];
	parity[840] = INITP_06[145:144];
	parity[841] = INITP_06[147:146];
	parity[842] = INITP_06[149:148];
	parity[843] = INITP_06[151:150];
	parity[844] = INITP_06[153:152];
	parity[845] = INITP_06[155:154];
	parity[846] = INITP_06[157:156];
	parity[847] = INITP_06[159:158];
	parity[848] = INITP_06[161:160];
	parity[849] = INITP_06[163:162];
	parity[850] = INITP_06[165:164];
	parity[851] = INITP_06[167:166];
	parity[852] = INITP_06[169:168];
	parity[853] = INITP_06[171:170];
	parity[854] = INITP_06[173:172];
	parity[855] = INITP_06[175:174];
	parity[856] = INITP_06[177:176];
	parity[857] = INITP_06[179:178];
	parity[858] = INITP_06[181:180];
	parity[859] = INITP_06[183:182];
	parity[860] = INITP_06[185:184];
	parity[861] = INITP_06[187:186];
	parity[862] = INITP_06[189:188];
	parity[863] = INITP_06[191:190];
	parity[864] = INITP_06[193:192];
	parity[865] = INITP_06[195:194];
	parity[866] = INITP_06[197:196];
	parity[867] = INITP_06[199:198];
	parity[868] = INITP_06[201:200];
	parity[869] = INITP_06[203:202];
	parity[870] = INITP_06[205:204];
	parity[871] = INITP_06[207:206];
	parity[872] = INITP_06[209:208];
	parity[873] = INITP_06[211:210];
	parity[874] = INITP_06[213:212];
	parity[875] = INITP_06[215:214];
	parity[876] = INITP_06[217:216];
	parity[877] = INITP_06[219:218];
	parity[878] = INITP_06[221:220];
	parity[879] = INITP_06[223:222];
	parity[880] = INITP_06[225:224];
	parity[881] = INITP_06[227:226];
	parity[882] = INITP_06[229:228];
	parity[883] = INITP_06[231:230];
	parity[884] = INITP_06[233:232];
	parity[885] = INITP_06[235:234];
	parity[886] = INITP_06[237:236];
	parity[887] = INITP_06[239:238];
	parity[888] = INITP_06[241:240];
	parity[889] = INITP_06[243:242];
	parity[890] = INITP_06[245:244];
	parity[891] = INITP_06[247:246];
	parity[892] = INITP_06[249:248];
	parity[893] = INITP_06[251:250];
	parity[894] = INITP_06[253:252];
	parity[895] = INITP_06[255:254];
	parity[896] = INITP_07[1:0];
	parity[897] = INITP_07[3:2];
	parity[898] = INITP_07[5:4];
	parity[899] = INITP_07[7:6];
	parity[900] = INITP_07[9:8];
	parity[901] = INITP_07[11:10];
	parity[902] = INITP_07[13:12];
	parity[903] = INITP_07[15:14];
	parity[904] = INITP_07[17:16];
	parity[905] = INITP_07[19:18];
	parity[906] = INITP_07[21:20];
	parity[907] = INITP_07[23:22];
	parity[908] = INITP_07[25:24];
	parity[909] = INITP_07[27:26];
	parity[910] = INITP_07[29:28];
	parity[911] = INITP_07[31:30];
	parity[912] = INITP_07[33:32];
	parity[913] = INITP_07[35:34];
	parity[914] = INITP_07[37:36];
	parity[915] = INITP_07[39:38];
	parity[916] = INITP_07[41:40];
	parity[917] = INITP_07[43:42];
	parity[918] = INITP_07[45:44];
	parity[919] = INITP_07[47:46];
	parity[920] = INITP_07[49:48];
	parity[921] = INITP_07[51:50];
	parity[922] = INITP_07[53:52];
	parity[923] = INITP_07[55:54];
	parity[924] = INITP_07[57:56];
	parity[925] = INITP_07[59:58];
	parity[926] = INITP_07[61:60];
	parity[927] = INITP_07[63:62];
	parity[928] = INITP_07[65:64];
	parity[929] = INITP_07[67:66];
	parity[930] = INITP_07[69:68];
	parity[931] = INITP_07[71:70];
	parity[932] = INITP_07[73:72];
	parity[933] = INITP_07[75:74];
	parity[934] = INITP_07[77:76];
	parity[935] = INITP_07[79:78];
	parity[936] = INITP_07[81:80];
	parity[937] = INITP_07[83:82];
	parity[938] = INITP_07[85:84];
	parity[939] = INITP_07[87:86];
	parity[940] = INITP_07[89:88];
	parity[941] = INITP_07[91:90];
	parity[942] = INITP_07[93:92];
	parity[943] = INITP_07[95:94];
	parity[944] = INITP_07[97:96];
	parity[945] = INITP_07[99:98];
	parity[946] = INITP_07[101:100];
	parity[947] = INITP_07[103:102];
	parity[948] = INITP_07[105:104];
	parity[949] = INITP_07[107:106];
	parity[950] = INITP_07[109:108];
	parity[951] = INITP_07[111:110];
	parity[952] = INITP_07[113:112];
	parity[953] = INITP_07[115:114];
	parity[954] = INITP_07[117:116];
	parity[955] = INITP_07[119:118];
	parity[956] = INITP_07[121:120];
	parity[957] = INITP_07[123:122];
	parity[958] = INITP_07[125:124];
	parity[959] = INITP_07[127:126];
	parity[960] = INITP_07[129:128];
	parity[961] = INITP_07[131:130];
	parity[962] = INITP_07[133:132];
	parity[963] = INITP_07[135:134];
	parity[964] = INITP_07[137:136];
	parity[965] = INITP_07[139:138];
	parity[966] = INITP_07[141:140];
	parity[967] = INITP_07[143:142];
	parity[968] = INITP_07[145:144];
	parity[969] = INITP_07[147:146];
	parity[970] = INITP_07[149:148];
	parity[971] = INITP_07[151:150];
	parity[972] = INITP_07[153:152];
	parity[973] = INITP_07[155:154];
	parity[974] = INITP_07[157:156];
	parity[975] = INITP_07[159:158];
	parity[976] = INITP_07[161:160];
	parity[977] = INITP_07[163:162];
	parity[978] = INITP_07[165:164];
	parity[979] = INITP_07[167:166];
	parity[980] = INITP_07[169:168];
	parity[981] = INITP_07[171:170];
	parity[982] = INITP_07[173:172];
	parity[983] = INITP_07[175:174];
	parity[984] = INITP_07[177:176];
	parity[985] = INITP_07[179:178];
	parity[986] = INITP_07[181:180];
	parity[987] = INITP_07[183:182];
	parity[988] = INITP_07[185:184];
	parity[989] = INITP_07[187:186];
	parity[990] = INITP_07[189:188];
	parity[991] = INITP_07[191:190];
	parity[992] = INITP_07[193:192];
	parity[993] = INITP_07[195:194];
	parity[994] = INITP_07[197:196];
	parity[995] = INITP_07[199:198];
	parity[996] = INITP_07[201:200];
	parity[997] = INITP_07[203:202];
	parity[998] = INITP_07[205:204];
	parity[999] = INITP_07[207:206];
	parity[1000] = INITP_07[209:208];
	parity[1001] = INITP_07[211:210];
	parity[1002] = INITP_07[213:212];
	parity[1003] = INITP_07[215:214];
	parity[1004] = INITP_07[217:216];
	parity[1005] = INITP_07[219:218];
	parity[1006] = INITP_07[221:220];
	parity[1007] = INITP_07[223:222];
	parity[1008] = INITP_07[225:224];
	parity[1009] = INITP_07[227:226];
	parity[1010] = INITP_07[229:228];
	parity[1011] = INITP_07[231:230];
	parity[1012] = INITP_07[233:232];
	parity[1013] = INITP_07[235:234];
	parity[1014] = INITP_07[237:236];
	parity[1015] = INITP_07[239:238];
	parity[1016] = INITP_07[241:240];
	parity[1017] = INITP_07[243:242];
	parity[1018] = INITP_07[245:244];
	parity[1019] = INITP_07[247:246];
	parity[1020] = INITP_07[249:248];
	parity[1021] = INITP_07[251:250];
	parity[1022] = INITP_07[253:252];
	parity[1023] = INITP_07[255:254];
end

endmodule

module RAMB16BWE_S18_S18(DOA, DOB, DOPA, DOPB, DIA, DIB, DIPA, DIPB,
		ADDRA, ADDRB, WEA, WEB, ENA, ENB, SSRA, SSRB,
		CLKA, CLKB);

parameter [17:0] SRVAL_A = 0;
parameter [17:0] SRVAL_B = 0;
parameter [255:0] INIT_00 = 0;
parameter [255:0] INIT_01 = 0;
parameter [255:0] INIT_02 = 0;
parameter [255:0] INIT_03 = 0;
parameter [255:0] INIT_04 = 0;
parameter [255:0] INIT_05 = 0;
parameter [255:0] INIT_06 = 0;
parameter [255:0] INIT_07 = 0;
parameter [255:0] INIT_08 = 0;
parameter [255:0] INIT_09 = 0;
parameter [255:0] INIT_0A = 0;
parameter [255:0] INIT_0B = 0;
parameter [255:0] INIT_0C = 0;
parameter [255:0] INIT_0D = 0;
parameter [255:0] INIT_0E = 0;
parameter [255:0] INIT_0F = 0;
parameter [255:0] INIT_10 = 0;
parameter [255:0] INIT_11 = 0;
parameter [255:0] INIT_12 = 0;
parameter [255:0] INIT_13 = 0;
parameter [255:0] INIT_14 = 0;
parameter [255:0] INIT_15 = 0;
parameter [255:0] INIT_16 = 0;
parameter [255:0] INIT_17 = 0;
parameter [255:0] INIT_18 = 0;
parameter [255:0] INIT_19 = 0;
parameter [255:0] INIT_1A = 0;
parameter [255:0] INIT_1B = 0;
parameter [255:0] INIT_1C = 0;
parameter [255:0] INIT_1D = 0;
parameter [255:0] INIT_1E = 0;
parameter [255:0] INIT_1F = 0;
parameter [255:0] INIT_20 = 0;
parameter [255:0] INIT_21 = 0;
parameter [255:0] INIT_22 = 0;
parameter [255:0] INIT_23 = 0;
parameter [255:0] INIT_24 = 0;
parameter [255:0] INIT_25 = 0;
parameter [255:0] INIT_26 = 0;
parameter [255:0] INIT_27 = 0;
parameter [255:0] INIT_28 = 0;
parameter [255:0] INIT_29 = 0;
parameter [255:0] INIT_2A = 0;
parameter [255:0] INIT_2B = 0;
parameter [255:0] INIT_2C = 0;
parameter [255:0] INIT_2D = 0;
parameter [255:0] INIT_2E = 0;
parameter [255:0] INIT_2F = 0;
parameter [255:0] INIT_30 = 0;
parameter [255:0] INIT_31 = 0;
parameter [255:0] INIT_32 = 0;
parameter [255:0] INIT_33 = 0;
parameter [255:0] INIT_34 = 0;
parameter [255:0] INIT_35 = 0;
parameter [255:0] INIT_36 = 0;
parameter [255:0] INIT_37 = 0;
parameter [255:0] INIT_38 = 0;
parameter [255:0] INIT_39 = 0;
parameter [255:0] INIT_3A = 0;
parameter [255:0] INIT_3B = 0;
parameter [255:0] INIT_3C = 0;
parameter [255:0] INIT_3D = 0;
parameter [255:0] INIT_3E = 0;
parameter [255:0] INIT_3F = 0;
parameter [255:0] INITP_00 = 0;
parameter [255:0] INITP_01 = 0;
parameter [255:0] INITP_02 = 0;
parameter [255:0] INITP_03 = 0;
parameter [255:0] INITP_04 = 0;
parameter [255:0] INITP_05 = 0;
parameter [255:0] INITP_06 = 0;
parameter [255:0] INITP_07 = 0;

output [15:0] DOA;
output [15:0] DOB;
output [1:0] DOPA;
output [1:0] DOPB;
input [15:0] DIA;
input [15:0] DIB;
input [1:0] DIPA;
input [1:0] DIPB;
input [9:0] ADDRA;
input [9:0] ADDRB;
input [1:0] WEA;
input [1:0] WEB;
input ENA;
input ENB;
input SSRA;
input SSRB;
input CLKA;
input CLKB;

reg [15:0] data[0:1023];
reg [1:0] parity[0:1023];

wire [15:0] data_a = data[ADDRA];
wire [15:0] data_b = data[ADDRB];
wire [1:0] parity_a = parity[ADDRA];
wire [1:0] parity_b = parity[ADDRB];

always @(posedge CLKA)
	if (ENA) begin
		case (WEA)
		0: ;
		1: data[ADDRA] <= { data_a[15:8], DIA[7:0] };
		2: data[ADDRA] <= { DIA[15:8], data_a[7:0] };
		3: data[ADDRA] <= DIA;
		endcase
	end

always @(posedge CLKA)
	if (ENA) begin
		case (WEA)
		0: ;
		1: parity[ADDRA] <= { parity_a[1], DIPA[0] };
		2: parity[ADDRA] <= { DIPA[1], parity_a[0] };
		3: parity[ADDRA] <= DIPA;
		endcase
	end

always @(posedge CLKB)
	if (ENB) begin
		case (WEB)
		0: ;
		1: data[ADDRB] <= { data_b[15:8], DIB[7:0] };
		2: data[ADDRB] <= { DIB[15:8], data_b[7:0] };
		3: data[ADDRB] <= DIB;
		endcase
	end

always @(posedge CLKB)
	if (ENB) begin
		case (WEB)
		0: ;
		1: parity[ADDRB] <= { parity_b[1], DIPB[0] };
		2: parity[ADDRB] <= { DIPB[1], parity_b[0] };
		3: parity[ADDRB] <= DIPB;
		endcase
	end

reg [15:0] DOA = 0;
always @(posedge CLKA)
	if (ENA) begin
		if (SSRA)
			DOA <= SRVAL_A[15:0];
		else
			DOA <= data_a;
	end

reg [15:0] DOB = 0;
always @(posedge CLKB)
	if (ENB) begin
		if (SSRB)
			DOB <= SRVAL_B[15:0];
		else
			DOB <= data_b;
	end

initial begin
	data[0] = INIT_00[15:0];
	data[1] = INIT_00[31:16];
	data[2] = INIT_00[47:32];
	data[3] = INIT_00[63:48];
	data[4] = INIT_00[79:64];
	data[5] = INIT_00[95:80];
	data[6] = INIT_00[111:96];
	data[7] = INIT_00[127:112];
	data[8] = INIT_00[143:128];
	data[9] = INIT_00[159:144];
	data[10] = INIT_00[175:160];
	data[11] = INIT_00[191:176];
	data[12] = INIT_00[207:192];
	data[13] = INIT_00[223:208];
	data[14] = INIT_00[239:224];
	data[15] = INIT_00[255:240];
	data[16] = INIT_01[15:0];
	data[17] = INIT_01[31:16];
	data[18] = INIT_01[47:32];
	data[19] = INIT_01[63:48];
	data[20] = INIT_01[79:64];
	data[21] = INIT_01[95:80];
	data[22] = INIT_01[111:96];
	data[23] = INIT_01[127:112];
	data[24] = INIT_01[143:128];
	data[25] = INIT_01[159:144];
	data[26] = INIT_01[175:160];
	data[27] = INIT_01[191:176];
	data[28] = INIT_01[207:192];
	data[29] = INIT_01[223:208];
	data[30] = INIT_01[239:224];
	data[31] = INIT_01[255:240];
	data[32] = INIT_02[15:0];
	data[33] = INIT_02[31:16];
	data[34] = INIT_02[47:32];
	data[35] = INIT_02[63:48];
	data[36] = INIT_02[79:64];
	data[37] = INIT_02[95:80];
	data[38] = INIT_02[111:96];
	data[39] = INIT_02[127:112];
	data[40] = INIT_02[143:128];
	data[41] = INIT_02[159:144];
	data[42] = INIT_02[175:160];
	data[43] = INIT_02[191:176];
	data[44] = INIT_02[207:192];
	data[45] = INIT_02[223:208];
	data[46] = INIT_02[239:224];
	data[47] = INIT_02[255:240];
	data[48] = INIT_03[15:0];
	data[49] = INIT_03[31:16];
	data[50] = INIT_03[47:32];
	data[51] = INIT_03[63:48];
	data[52] = INIT_03[79:64];
	data[53] = INIT_03[95:80];
	data[54] = INIT_03[111:96];
	data[55] = INIT_03[127:112];
	data[56] = INIT_03[143:128];
	data[57] = INIT_03[159:144];
	data[58] = INIT_03[175:160];
	data[59] = INIT_03[191:176];
	data[60] = INIT_03[207:192];
	data[61] = INIT_03[223:208];
	data[62] = INIT_03[239:224];
	data[63] = INIT_03[255:240];
	data[64] = INIT_04[15:0];
	data[65] = INIT_04[31:16];
	data[66] = INIT_04[47:32];
	data[67] = INIT_04[63:48];
	data[68] = INIT_04[79:64];
	data[69] = INIT_04[95:80];
	data[70] = INIT_04[111:96];
	data[71] = INIT_04[127:112];
	data[72] = INIT_04[143:128];
	data[73] = INIT_04[159:144];
	data[74] = INIT_04[175:160];
	data[75] = INIT_04[191:176];
	data[76] = INIT_04[207:192];
	data[77] = INIT_04[223:208];
	data[78] = INIT_04[239:224];
	data[79] = INIT_04[255:240];
	data[80] = INIT_05[15:0];
	data[81] = INIT_05[31:16];
	data[82] = INIT_05[47:32];
	data[83] = INIT_05[63:48];
	data[84] = INIT_05[79:64];
	data[85] = INIT_05[95:80];
	data[86] = INIT_05[111:96];
	data[87] = INIT_05[127:112];
	data[88] = INIT_05[143:128];
	data[89] = INIT_05[159:144];
	data[90] = INIT_05[175:160];
	data[91] = INIT_05[191:176];
	data[92] = INIT_05[207:192];
	data[93] = INIT_05[223:208];
	data[94] = INIT_05[239:224];
	data[95] = INIT_05[255:240];
	data[96] = INIT_06[15:0];
	data[97] = INIT_06[31:16];
	data[98] = INIT_06[47:32];
	data[99] = INIT_06[63:48];
	data[100] = INIT_06[79:64];
	data[101] = INIT_06[95:80];
	data[102] = INIT_06[111:96];
	data[103] = INIT_06[127:112];
	data[104] = INIT_06[143:128];
	data[105] = INIT_06[159:144];
	data[106] = INIT_06[175:160];
	data[107] = INIT_06[191:176];
	data[108] = INIT_06[207:192];
	data[109] = INIT_06[223:208];
	data[110] = INIT_06[239:224];
	data[111] = INIT_06[255:240];
	data[112] = INIT_07[15:0];
	data[113] = INIT_07[31:16];
	data[114] = INIT_07[47:32];
	data[115] = INIT_07[63:48];
	data[116] = INIT_07[79:64];
	data[117] = INIT_07[95:80];
	data[118] = INIT_07[111:96];
	data[119] = INIT_07[127:112];
	data[120] = INIT_07[143:128];
	data[121] = INIT_07[159:144];
	data[122] = INIT_07[175:160];
	data[123] = INIT_07[191:176];
	data[124] = INIT_07[207:192];
	data[125] = INIT_07[223:208];
	data[126] = INIT_07[239:224];
	data[127] = INIT_07[255:240];
	data[128] = INIT_08[15:0];
	data[129] = INIT_08[31:16];
	data[130] = INIT_08[47:32];
	data[131] = INIT_08[63:48];
	data[132] = INIT_08[79:64];
	data[133] = INIT_08[95:80];
	data[134] = INIT_08[111:96];
	data[135] = INIT_08[127:112];
	data[136] = INIT_08[143:128];
	data[137] = INIT_08[159:144];
	data[138] = INIT_08[175:160];
	data[139] = INIT_08[191:176];
	data[140] = INIT_08[207:192];
	data[141] = INIT_08[223:208];
	data[142] = INIT_08[239:224];
	data[143] = INIT_08[255:240];
	data[144] = INIT_09[15:0];
	data[145] = INIT_09[31:16];
	data[146] = INIT_09[47:32];
	data[147] = INIT_09[63:48];
	data[148] = INIT_09[79:64];
	data[149] = INIT_09[95:80];
	data[150] = INIT_09[111:96];
	data[151] = INIT_09[127:112];
	data[152] = INIT_09[143:128];
	data[153] = INIT_09[159:144];
	data[154] = INIT_09[175:160];
	data[155] = INIT_09[191:176];
	data[156] = INIT_09[207:192];
	data[157] = INIT_09[223:208];
	data[158] = INIT_09[239:224];
	data[159] = INIT_09[255:240];
	data[160] = INIT_0A[15:0];
	data[161] = INIT_0A[31:16];
	data[162] = INIT_0A[47:32];
	data[163] = INIT_0A[63:48];
	data[164] = INIT_0A[79:64];
	data[165] = INIT_0A[95:80];
	data[166] = INIT_0A[111:96];
	data[167] = INIT_0A[127:112];
	data[168] = INIT_0A[143:128];
	data[169] = INIT_0A[159:144];
	data[170] = INIT_0A[175:160];
	data[171] = INIT_0A[191:176];
	data[172] = INIT_0A[207:192];
	data[173] = INIT_0A[223:208];
	data[174] = INIT_0A[239:224];
	data[175] = INIT_0A[255:240];
	data[176] = INIT_0B[15:0];
	data[177] = INIT_0B[31:16];
	data[178] = INIT_0B[47:32];
	data[179] = INIT_0B[63:48];
	data[180] = INIT_0B[79:64];
	data[181] = INIT_0B[95:80];
	data[182] = INIT_0B[111:96];
	data[183] = INIT_0B[127:112];
	data[184] = INIT_0B[143:128];
	data[185] = INIT_0B[159:144];
	data[186] = INIT_0B[175:160];
	data[187] = INIT_0B[191:176];
	data[188] = INIT_0B[207:192];
	data[189] = INIT_0B[223:208];
	data[190] = INIT_0B[239:224];
	data[191] = INIT_0B[255:240];
	data[192] = INIT_0C[15:0];
	data[193] = INIT_0C[31:16];
	data[194] = INIT_0C[47:32];
	data[195] = INIT_0C[63:48];
	data[196] = INIT_0C[79:64];
	data[197] = INIT_0C[95:80];
	data[198] = INIT_0C[111:96];
	data[199] = INIT_0C[127:112];
	data[200] = INIT_0C[143:128];
	data[201] = INIT_0C[159:144];
	data[202] = INIT_0C[175:160];
	data[203] = INIT_0C[191:176];
	data[204] = INIT_0C[207:192];
	data[205] = INIT_0C[223:208];
	data[206] = INIT_0C[239:224];
	data[207] = INIT_0C[255:240];
	data[208] = INIT_0D[15:0];
	data[209] = INIT_0D[31:16];
	data[210] = INIT_0D[47:32];
	data[211] = INIT_0D[63:48];
	data[212] = INIT_0D[79:64];
	data[213] = INIT_0D[95:80];
	data[214] = INIT_0D[111:96];
	data[215] = INIT_0D[127:112];
	data[216] = INIT_0D[143:128];
	data[217] = INIT_0D[159:144];
	data[218] = INIT_0D[175:160];
	data[219] = INIT_0D[191:176];
	data[220] = INIT_0D[207:192];
	data[221] = INIT_0D[223:208];
	data[222] = INIT_0D[239:224];
	data[223] = INIT_0D[255:240];
	data[224] = INIT_0E[15:0];
	data[225] = INIT_0E[31:16];
	data[226] = INIT_0E[47:32];
	data[227] = INIT_0E[63:48];
	data[228] = INIT_0E[79:64];
	data[229] = INIT_0E[95:80];
	data[230] = INIT_0E[111:96];
	data[231] = INIT_0E[127:112];
	data[232] = INIT_0E[143:128];
	data[233] = INIT_0E[159:144];
	data[234] = INIT_0E[175:160];
	data[235] = INIT_0E[191:176];
	data[236] = INIT_0E[207:192];
	data[237] = INIT_0E[223:208];
	data[238] = INIT_0E[239:224];
	data[239] = INIT_0E[255:240];
	data[240] = INIT_0F[15:0];
	data[241] = INIT_0F[31:16];
	data[242] = INIT_0F[47:32];
	data[243] = INIT_0F[63:48];
	data[244] = INIT_0F[79:64];
	data[245] = INIT_0F[95:80];
	data[246] = INIT_0F[111:96];
	data[247] = INIT_0F[127:112];
	data[248] = INIT_0F[143:128];
	data[249] = INIT_0F[159:144];
	data[250] = INIT_0F[175:160];
	data[251] = INIT_0F[191:176];
	data[252] = INIT_0F[207:192];
	data[253] = INIT_0F[223:208];
	data[254] = INIT_0F[239:224];
	data[255] = INIT_0F[255:240];
	data[256] = INIT_10[15:0];
	data[257] = INIT_10[31:16];
	data[258] = INIT_10[47:32];
	data[259] = INIT_10[63:48];
	data[260] = INIT_10[79:64];
	data[261] = INIT_10[95:80];
	data[262] = INIT_10[111:96];
	data[263] = INIT_10[127:112];
	data[264] = INIT_10[143:128];
	data[265] = INIT_10[159:144];
	data[266] = INIT_10[175:160];
	data[267] = INIT_10[191:176];
	data[268] = INIT_10[207:192];
	data[269] = INIT_10[223:208];
	data[270] = INIT_10[239:224];
	data[271] = INIT_10[255:240];
	data[272] = INIT_11[15:0];
	data[273] = INIT_11[31:16];
	data[274] = INIT_11[47:32];
	data[275] = INIT_11[63:48];
	data[276] = INIT_11[79:64];
	data[277] = INIT_11[95:80];
	data[278] = INIT_11[111:96];
	data[279] = INIT_11[127:112];
	data[280] = INIT_11[143:128];
	data[281] = INIT_11[159:144];
	data[282] = INIT_11[175:160];
	data[283] = INIT_11[191:176];
	data[284] = INIT_11[207:192];
	data[285] = INIT_11[223:208];
	data[286] = INIT_11[239:224];
	data[287] = INIT_11[255:240];
	data[288] = INIT_12[15:0];
	data[289] = INIT_12[31:16];
	data[290] = INIT_12[47:32];
	data[291] = INIT_12[63:48];
	data[292] = INIT_12[79:64];
	data[293] = INIT_12[95:80];
	data[294] = INIT_12[111:96];
	data[295] = INIT_12[127:112];
	data[296] = INIT_12[143:128];
	data[297] = INIT_12[159:144];
	data[298] = INIT_12[175:160];
	data[299] = INIT_12[191:176];
	data[300] = INIT_12[207:192];
	data[301] = INIT_12[223:208];
	data[302] = INIT_12[239:224];
	data[303] = INIT_12[255:240];
	data[304] = INIT_13[15:0];
	data[305] = INIT_13[31:16];
	data[306] = INIT_13[47:32];
	data[307] = INIT_13[63:48];
	data[308] = INIT_13[79:64];
	data[309] = INIT_13[95:80];
	data[310] = INIT_13[111:96];
	data[311] = INIT_13[127:112];
	data[312] = INIT_13[143:128];
	data[313] = INIT_13[159:144];
	data[314] = INIT_13[175:160];
	data[315] = INIT_13[191:176];
	data[316] = INIT_13[207:192];
	data[317] = INIT_13[223:208];
	data[318] = INIT_13[239:224];
	data[319] = INIT_13[255:240];
	data[320] = INIT_14[15:0];
	data[321] = INIT_14[31:16];
	data[322] = INIT_14[47:32];
	data[323] = INIT_14[63:48];
	data[324] = INIT_14[79:64];
	data[325] = INIT_14[95:80];
	data[326] = INIT_14[111:96];
	data[327] = INIT_14[127:112];
	data[328] = INIT_14[143:128];
	data[329] = INIT_14[159:144];
	data[330] = INIT_14[175:160];
	data[331] = INIT_14[191:176];
	data[332] = INIT_14[207:192];
	data[333] = INIT_14[223:208];
	data[334] = INIT_14[239:224];
	data[335] = INIT_14[255:240];
	data[336] = INIT_15[15:0];
	data[337] = INIT_15[31:16];
	data[338] = INIT_15[47:32];
	data[339] = INIT_15[63:48];
	data[340] = INIT_15[79:64];
	data[341] = INIT_15[95:80];
	data[342] = INIT_15[111:96];
	data[343] = INIT_15[127:112];
	data[344] = INIT_15[143:128];
	data[345] = INIT_15[159:144];
	data[346] = INIT_15[175:160];
	data[347] = INIT_15[191:176];
	data[348] = INIT_15[207:192];
	data[349] = INIT_15[223:208];
	data[350] = INIT_15[239:224];
	data[351] = INIT_15[255:240];
	data[352] = INIT_16[15:0];
	data[353] = INIT_16[31:16];
	data[354] = INIT_16[47:32];
	data[355] = INIT_16[63:48];
	data[356] = INIT_16[79:64];
	data[357] = INIT_16[95:80];
	data[358] = INIT_16[111:96];
	data[359] = INIT_16[127:112];
	data[360] = INIT_16[143:128];
	data[361] = INIT_16[159:144];
	data[362] = INIT_16[175:160];
	data[363] = INIT_16[191:176];
	data[364] = INIT_16[207:192];
	data[365] = INIT_16[223:208];
	data[366] = INIT_16[239:224];
	data[367] = INIT_16[255:240];
	data[368] = INIT_17[15:0];
	data[369] = INIT_17[31:16];
	data[370] = INIT_17[47:32];
	data[371] = INIT_17[63:48];
	data[372] = INIT_17[79:64];
	data[373] = INIT_17[95:80];
	data[374] = INIT_17[111:96];
	data[375] = INIT_17[127:112];
	data[376] = INIT_17[143:128];
	data[377] = INIT_17[159:144];
	data[378] = INIT_17[175:160];
	data[379] = INIT_17[191:176];
	data[380] = INIT_17[207:192];
	data[381] = INIT_17[223:208];
	data[382] = INIT_17[239:224];
	data[383] = INIT_17[255:240];
	data[384] = INIT_18[15:0];
	data[385] = INIT_18[31:16];
	data[386] = INIT_18[47:32];
	data[387] = INIT_18[63:48];
	data[388] = INIT_18[79:64];
	data[389] = INIT_18[95:80];
	data[390] = INIT_18[111:96];
	data[391] = INIT_18[127:112];
	data[392] = INIT_18[143:128];
	data[393] = INIT_18[159:144];
	data[394] = INIT_18[175:160];
	data[395] = INIT_18[191:176];
	data[396] = INIT_18[207:192];
	data[397] = INIT_18[223:208];
	data[398] = INIT_18[239:224];
	data[399] = INIT_18[255:240];
	data[400] = INIT_19[15:0];
	data[401] = INIT_19[31:16];
	data[402] = INIT_19[47:32];
	data[403] = INIT_19[63:48];
	data[404] = INIT_19[79:64];
	data[405] = INIT_19[95:80];
	data[406] = INIT_19[111:96];
	data[407] = INIT_19[127:112];
	data[408] = INIT_19[143:128];
	data[409] = INIT_19[159:144];
	data[410] = INIT_19[175:160];
	data[411] = INIT_19[191:176];
	data[412] = INIT_19[207:192];
	data[413] = INIT_19[223:208];
	data[414] = INIT_19[239:224];
	data[415] = INIT_19[255:240];
	data[416] = INIT_1A[15:0];
	data[417] = INIT_1A[31:16];
	data[418] = INIT_1A[47:32];
	data[419] = INIT_1A[63:48];
	data[420] = INIT_1A[79:64];
	data[421] = INIT_1A[95:80];
	data[422] = INIT_1A[111:96];
	data[423] = INIT_1A[127:112];
	data[424] = INIT_1A[143:128];
	data[425] = INIT_1A[159:144];
	data[426] = INIT_1A[175:160];
	data[427] = INIT_1A[191:176];
	data[428] = INIT_1A[207:192];
	data[429] = INIT_1A[223:208];
	data[430] = INIT_1A[239:224];
	data[431] = INIT_1A[255:240];
	data[432] = INIT_1B[15:0];
	data[433] = INIT_1B[31:16];
	data[434] = INIT_1B[47:32];
	data[435] = INIT_1B[63:48];
	data[436] = INIT_1B[79:64];
	data[437] = INIT_1B[95:80];
	data[438] = INIT_1B[111:96];
	data[439] = INIT_1B[127:112];
	data[440] = INIT_1B[143:128];
	data[441] = INIT_1B[159:144];
	data[442] = INIT_1B[175:160];
	data[443] = INIT_1B[191:176];
	data[444] = INIT_1B[207:192];
	data[445] = INIT_1B[223:208];
	data[446] = INIT_1B[239:224];
	data[447] = INIT_1B[255:240];
	data[448] = INIT_1C[15:0];
	data[449] = INIT_1C[31:16];
	data[450] = INIT_1C[47:32];
	data[451] = INIT_1C[63:48];
	data[452] = INIT_1C[79:64];
	data[453] = INIT_1C[95:80];
	data[454] = INIT_1C[111:96];
	data[455] = INIT_1C[127:112];
	data[456] = INIT_1C[143:128];
	data[457] = INIT_1C[159:144];
	data[458] = INIT_1C[175:160];
	data[459] = INIT_1C[191:176];
	data[460] = INIT_1C[207:192];
	data[461] = INIT_1C[223:208];
	data[462] = INIT_1C[239:224];
	data[463] = INIT_1C[255:240];
	data[464] = INIT_1D[15:0];
	data[465] = INIT_1D[31:16];
	data[466] = INIT_1D[47:32];
	data[467] = INIT_1D[63:48];
	data[468] = INIT_1D[79:64];
	data[469] = INIT_1D[95:80];
	data[470] = INIT_1D[111:96];
	data[471] = INIT_1D[127:112];
	data[472] = INIT_1D[143:128];
	data[473] = INIT_1D[159:144];
	data[474] = INIT_1D[175:160];
	data[475] = INIT_1D[191:176];
	data[476] = INIT_1D[207:192];
	data[477] = INIT_1D[223:208];
	data[478] = INIT_1D[239:224];
	data[479] = INIT_1D[255:240];
	data[480] = INIT_1E[15:0];
	data[481] = INIT_1E[31:16];
	data[482] = INIT_1E[47:32];
	data[483] = INIT_1E[63:48];
	data[484] = INIT_1E[79:64];
	data[485] = INIT_1E[95:80];
	data[486] = INIT_1E[111:96];
	data[487] = INIT_1E[127:112];
	data[488] = INIT_1E[143:128];
	data[489] = INIT_1E[159:144];
	data[490] = INIT_1E[175:160];
	data[491] = INIT_1E[191:176];
	data[492] = INIT_1E[207:192];
	data[493] = INIT_1E[223:208];
	data[494] = INIT_1E[239:224];
	data[495] = INIT_1E[255:240];
	data[496] = INIT_1F[15:0];
	data[497] = INIT_1F[31:16];
	data[498] = INIT_1F[47:32];
	data[499] = INIT_1F[63:48];
	data[500] = INIT_1F[79:64];
	data[501] = INIT_1F[95:80];
	data[502] = INIT_1F[111:96];
	data[503] = INIT_1F[127:112];
	data[504] = INIT_1F[143:128];
	data[505] = INIT_1F[159:144];
	data[506] = INIT_1F[175:160];
	data[507] = INIT_1F[191:176];
	data[508] = INIT_1F[207:192];
	data[509] = INIT_1F[223:208];
	data[510] = INIT_1F[239:224];
	data[511] = INIT_1F[255:240];
	data[512] = INIT_20[15:0];
	data[513] = INIT_20[31:16];
	data[514] = INIT_20[47:32];
	data[515] = INIT_20[63:48];
	data[516] = INIT_20[79:64];
	data[517] = INIT_20[95:80];
	data[518] = INIT_20[111:96];
	data[519] = INIT_20[127:112];
	data[520] = INIT_20[143:128];
	data[521] = INIT_20[159:144];
	data[522] = INIT_20[175:160];
	data[523] = INIT_20[191:176];
	data[524] = INIT_20[207:192];
	data[525] = INIT_20[223:208];
	data[526] = INIT_20[239:224];
	data[527] = INIT_20[255:240];
	data[528] = INIT_21[15:0];
	data[529] = INIT_21[31:16];
	data[530] = INIT_21[47:32];
	data[531] = INIT_21[63:48];
	data[532] = INIT_21[79:64];
	data[533] = INIT_21[95:80];
	data[534] = INIT_21[111:96];
	data[535] = INIT_21[127:112];
	data[536] = INIT_21[143:128];
	data[537] = INIT_21[159:144];
	data[538] = INIT_21[175:160];
	data[539] = INIT_21[191:176];
	data[540] = INIT_21[207:192];
	data[541] = INIT_21[223:208];
	data[542] = INIT_21[239:224];
	data[543] = INIT_21[255:240];
	data[544] = INIT_22[15:0];
	data[545] = INIT_22[31:16];
	data[546] = INIT_22[47:32];
	data[547] = INIT_22[63:48];
	data[548] = INIT_22[79:64];
	data[549] = INIT_22[95:80];
	data[550] = INIT_22[111:96];
	data[551] = INIT_22[127:112];
	data[552] = INIT_22[143:128];
	data[553] = INIT_22[159:144];
	data[554] = INIT_22[175:160];
	data[555] = INIT_22[191:176];
	data[556] = INIT_22[207:192];
	data[557] = INIT_22[223:208];
	data[558] = INIT_22[239:224];
	data[559] = INIT_22[255:240];
	data[560] = INIT_23[15:0];
	data[561] = INIT_23[31:16];
	data[562] = INIT_23[47:32];
	data[563] = INIT_23[63:48];
	data[564] = INIT_23[79:64];
	data[565] = INIT_23[95:80];
	data[566] = INIT_23[111:96];
	data[567] = INIT_23[127:112];
	data[568] = INIT_23[143:128];
	data[569] = INIT_23[159:144];
	data[570] = INIT_23[175:160];
	data[571] = INIT_23[191:176];
	data[572] = INIT_23[207:192];
	data[573] = INIT_23[223:208];
	data[574] = INIT_23[239:224];
	data[575] = INIT_23[255:240];
	data[576] = INIT_24[15:0];
	data[577] = INIT_24[31:16];
	data[578] = INIT_24[47:32];
	data[579] = INIT_24[63:48];
	data[580] = INIT_24[79:64];
	data[581] = INIT_24[95:80];
	data[582] = INIT_24[111:96];
	data[583] = INIT_24[127:112];
	data[584] = INIT_24[143:128];
	data[585] = INIT_24[159:144];
	data[586] = INIT_24[175:160];
	data[587] = INIT_24[191:176];
	data[588] = INIT_24[207:192];
	data[589] = INIT_24[223:208];
	data[590] = INIT_24[239:224];
	data[591] = INIT_24[255:240];
	data[592] = INIT_25[15:0];
	data[593] = INIT_25[31:16];
	data[594] = INIT_25[47:32];
	data[595] = INIT_25[63:48];
	data[596] = INIT_25[79:64];
	data[597] = INIT_25[95:80];
	data[598] = INIT_25[111:96];
	data[599] = INIT_25[127:112];
	data[600] = INIT_25[143:128];
	data[601] = INIT_25[159:144];
	data[602] = INIT_25[175:160];
	data[603] = INIT_25[191:176];
	data[604] = INIT_25[207:192];
	data[605] = INIT_25[223:208];
	data[606] = INIT_25[239:224];
	data[607] = INIT_25[255:240];
	data[608] = INIT_26[15:0];
	data[609] = INIT_26[31:16];
	data[610] = INIT_26[47:32];
	data[611] = INIT_26[63:48];
	data[612] = INIT_26[79:64];
	data[613] = INIT_26[95:80];
	data[614] = INIT_26[111:96];
	data[615] = INIT_26[127:112];
	data[616] = INIT_26[143:128];
	data[617] = INIT_26[159:144];
	data[618] = INIT_26[175:160];
	data[619] = INIT_26[191:176];
	data[620] = INIT_26[207:192];
	data[621] = INIT_26[223:208];
	data[622] = INIT_26[239:224];
	data[623] = INIT_26[255:240];
	data[624] = INIT_27[15:0];
	data[625] = INIT_27[31:16];
	data[626] = INIT_27[47:32];
	data[627] = INIT_27[63:48];
	data[628] = INIT_27[79:64];
	data[629] = INIT_27[95:80];
	data[630] = INIT_27[111:96];
	data[631] = INIT_27[127:112];
	data[632] = INIT_27[143:128];
	data[633] = INIT_27[159:144];
	data[634] = INIT_27[175:160];
	data[635] = INIT_27[191:176];
	data[636] = INIT_27[207:192];
	data[637] = INIT_27[223:208];
	data[638] = INIT_27[239:224];
	data[639] = INIT_27[255:240];
	data[640] = INIT_28[15:0];
	data[641] = INIT_28[31:16];
	data[642] = INIT_28[47:32];
	data[643] = INIT_28[63:48];
	data[644] = INIT_28[79:64];
	data[645] = INIT_28[95:80];
	data[646] = INIT_28[111:96];
	data[647] = INIT_28[127:112];
	data[648] = INIT_28[143:128];
	data[649] = INIT_28[159:144];
	data[650] = INIT_28[175:160];
	data[651] = INIT_28[191:176];
	data[652] = INIT_28[207:192];
	data[653] = INIT_28[223:208];
	data[654] = INIT_28[239:224];
	data[655] = INIT_28[255:240];
	data[656] = INIT_29[15:0];
	data[657] = INIT_29[31:16];
	data[658] = INIT_29[47:32];
	data[659] = INIT_29[63:48];
	data[660] = INIT_29[79:64];
	data[661] = INIT_29[95:80];
	data[662] = INIT_29[111:96];
	data[663] = INIT_29[127:112];
	data[664] = INIT_29[143:128];
	data[665] = INIT_29[159:144];
	data[666] = INIT_29[175:160];
	data[667] = INIT_29[191:176];
	data[668] = INIT_29[207:192];
	data[669] = INIT_29[223:208];
	data[670] = INIT_29[239:224];
	data[671] = INIT_29[255:240];
	data[672] = INIT_2A[15:0];
	data[673] = INIT_2A[31:16];
	data[674] = INIT_2A[47:32];
	data[675] = INIT_2A[63:48];
	data[676] = INIT_2A[79:64];
	data[677] = INIT_2A[95:80];
	data[678] = INIT_2A[111:96];
	data[679] = INIT_2A[127:112];
	data[680] = INIT_2A[143:128];
	data[681] = INIT_2A[159:144];
	data[682] = INIT_2A[175:160];
	data[683] = INIT_2A[191:176];
	data[684] = INIT_2A[207:192];
	data[685] = INIT_2A[223:208];
	data[686] = INIT_2A[239:224];
	data[687] = INIT_2A[255:240];
	data[688] = INIT_2B[15:0];
	data[689] = INIT_2B[31:16];
	data[690] = INIT_2B[47:32];
	data[691] = INIT_2B[63:48];
	data[692] = INIT_2B[79:64];
	data[693] = INIT_2B[95:80];
	data[694] = INIT_2B[111:96];
	data[695] = INIT_2B[127:112];
	data[696] = INIT_2B[143:128];
	data[697] = INIT_2B[159:144];
	data[698] = INIT_2B[175:160];
	data[699] = INIT_2B[191:176];
	data[700] = INIT_2B[207:192];
	data[701] = INIT_2B[223:208];
	data[702] = INIT_2B[239:224];
	data[703] = INIT_2B[255:240];
	data[704] = INIT_2C[15:0];
	data[705] = INIT_2C[31:16];
	data[706] = INIT_2C[47:32];
	data[707] = INIT_2C[63:48];
	data[708] = INIT_2C[79:64];
	data[709] = INIT_2C[95:80];
	data[710] = INIT_2C[111:96];
	data[711] = INIT_2C[127:112];
	data[712] = INIT_2C[143:128];
	data[713] = INIT_2C[159:144];
	data[714] = INIT_2C[175:160];
	data[715] = INIT_2C[191:176];
	data[716] = INIT_2C[207:192];
	data[717] = INIT_2C[223:208];
	data[718] = INIT_2C[239:224];
	data[719] = INIT_2C[255:240];
	data[720] = INIT_2D[15:0];
	data[721] = INIT_2D[31:16];
	data[722] = INIT_2D[47:32];
	data[723] = INIT_2D[63:48];
	data[724] = INIT_2D[79:64];
	data[725] = INIT_2D[95:80];
	data[726] = INIT_2D[111:96];
	data[727] = INIT_2D[127:112];
	data[728] = INIT_2D[143:128];
	data[729] = INIT_2D[159:144];
	data[730] = INIT_2D[175:160];
	data[731] = INIT_2D[191:176];
	data[732] = INIT_2D[207:192];
	data[733] = INIT_2D[223:208];
	data[734] = INIT_2D[239:224];
	data[735] = INIT_2D[255:240];
	data[736] = INIT_2E[15:0];
	data[737] = INIT_2E[31:16];
	data[738] = INIT_2E[47:32];
	data[739] = INIT_2E[63:48];
	data[740] = INIT_2E[79:64];
	data[741] = INIT_2E[95:80];
	data[742] = INIT_2E[111:96];
	data[743] = INIT_2E[127:112];
	data[744] = INIT_2E[143:128];
	data[745] = INIT_2E[159:144];
	data[746] = INIT_2E[175:160];
	data[747] = INIT_2E[191:176];
	data[748] = INIT_2E[207:192];
	data[749] = INIT_2E[223:208];
	data[750] = INIT_2E[239:224];
	data[751] = INIT_2E[255:240];
	data[752] = INIT_2F[15:0];
	data[753] = INIT_2F[31:16];
	data[754] = INIT_2F[47:32];
	data[755] = INIT_2F[63:48];
	data[756] = INIT_2F[79:64];
	data[757] = INIT_2F[95:80];
	data[758] = INIT_2F[111:96];
	data[759] = INIT_2F[127:112];
	data[760] = INIT_2F[143:128];
	data[761] = INIT_2F[159:144];
	data[762] = INIT_2F[175:160];
	data[763] = INIT_2F[191:176];
	data[764] = INIT_2F[207:192];
	data[765] = INIT_2F[223:208];
	data[766] = INIT_2F[239:224];
	data[767] = INIT_2F[255:240];
	data[768] = INIT_30[15:0];
	data[769] = INIT_30[31:16];
	data[770] = INIT_30[47:32];
	data[771] = INIT_30[63:48];
	data[772] = INIT_30[79:64];
	data[773] = INIT_30[95:80];
	data[774] = INIT_30[111:96];
	data[775] = INIT_30[127:112];
	data[776] = INIT_30[143:128];
	data[777] = INIT_30[159:144];
	data[778] = INIT_30[175:160];
	data[779] = INIT_30[191:176];
	data[780] = INIT_30[207:192];
	data[781] = INIT_30[223:208];
	data[782] = INIT_30[239:224];
	data[783] = INIT_30[255:240];
	data[784] = INIT_31[15:0];
	data[785] = INIT_31[31:16];
	data[786] = INIT_31[47:32];
	data[787] = INIT_31[63:48];
	data[788] = INIT_31[79:64];
	data[789] = INIT_31[95:80];
	data[790] = INIT_31[111:96];
	data[791] = INIT_31[127:112];
	data[792] = INIT_31[143:128];
	data[793] = INIT_31[159:144];
	data[794] = INIT_31[175:160];
	data[795] = INIT_31[191:176];
	data[796] = INIT_31[207:192];
	data[797] = INIT_31[223:208];
	data[798] = INIT_31[239:224];
	data[799] = INIT_31[255:240];
	data[800] = INIT_32[15:0];
	data[801] = INIT_32[31:16];
	data[802] = INIT_32[47:32];
	data[803] = INIT_32[63:48];
	data[804] = INIT_32[79:64];
	data[805] = INIT_32[95:80];
	data[806] = INIT_32[111:96];
	data[807] = INIT_32[127:112];
	data[808] = INIT_32[143:128];
	data[809] = INIT_32[159:144];
	data[810] = INIT_32[175:160];
	data[811] = INIT_32[191:176];
	data[812] = INIT_32[207:192];
	data[813] = INIT_32[223:208];
	data[814] = INIT_32[239:224];
	data[815] = INIT_32[255:240];
	data[816] = INIT_33[15:0];
	data[817] = INIT_33[31:16];
	data[818] = INIT_33[47:32];
	data[819] = INIT_33[63:48];
	data[820] = INIT_33[79:64];
	data[821] = INIT_33[95:80];
	data[822] = INIT_33[111:96];
	data[823] = INIT_33[127:112];
	data[824] = INIT_33[143:128];
	data[825] = INIT_33[159:144];
	data[826] = INIT_33[175:160];
	data[827] = INIT_33[191:176];
	data[828] = INIT_33[207:192];
	data[829] = INIT_33[223:208];
	data[830] = INIT_33[239:224];
	data[831] = INIT_33[255:240];
	data[832] = INIT_34[15:0];
	data[833] = INIT_34[31:16];
	data[834] = INIT_34[47:32];
	data[835] = INIT_34[63:48];
	data[836] = INIT_34[79:64];
	data[837] = INIT_34[95:80];
	data[838] = INIT_34[111:96];
	data[839] = INIT_34[127:112];
	data[840] = INIT_34[143:128];
	data[841] = INIT_34[159:144];
	data[842] = INIT_34[175:160];
	data[843] = INIT_34[191:176];
	data[844] = INIT_34[207:192];
	data[845] = INIT_34[223:208];
	data[846] = INIT_34[239:224];
	data[847] = INIT_34[255:240];
	data[848] = INIT_35[15:0];
	data[849] = INIT_35[31:16];
	data[850] = INIT_35[47:32];
	data[851] = INIT_35[63:48];
	data[852] = INIT_35[79:64];
	data[853] = INIT_35[95:80];
	data[854] = INIT_35[111:96];
	data[855] = INIT_35[127:112];
	data[856] = INIT_35[143:128];
	data[857] = INIT_35[159:144];
	data[858] = INIT_35[175:160];
	data[859] = INIT_35[191:176];
	data[860] = INIT_35[207:192];
	data[861] = INIT_35[223:208];
	data[862] = INIT_35[239:224];
	data[863] = INIT_35[255:240];
	data[864] = INIT_36[15:0];
	data[865] = INIT_36[31:16];
	data[866] = INIT_36[47:32];
	data[867] = INIT_36[63:48];
	data[868] = INIT_36[79:64];
	data[869] = INIT_36[95:80];
	data[870] = INIT_36[111:96];
	data[871] = INIT_36[127:112];
	data[872] = INIT_36[143:128];
	data[873] = INIT_36[159:144];
	data[874] = INIT_36[175:160];
	data[875] = INIT_36[191:176];
	data[876] = INIT_36[207:192];
	data[877] = INIT_36[223:208];
	data[878] = INIT_36[239:224];
	data[879] = INIT_36[255:240];
	data[880] = INIT_37[15:0];
	data[881] = INIT_37[31:16];
	data[882] = INIT_37[47:32];
	data[883] = INIT_37[63:48];
	data[884] = INIT_37[79:64];
	data[885] = INIT_37[95:80];
	data[886] = INIT_37[111:96];
	data[887] = INIT_37[127:112];
	data[888] = INIT_37[143:128];
	data[889] = INIT_37[159:144];
	data[890] = INIT_37[175:160];
	data[891] = INIT_37[191:176];
	data[892] = INIT_37[207:192];
	data[893] = INIT_37[223:208];
	data[894] = INIT_37[239:224];
	data[895] = INIT_37[255:240];
	data[896] = INIT_38[15:0];
	data[897] = INIT_38[31:16];
	data[898] = INIT_38[47:32];
	data[899] = INIT_38[63:48];
	data[900] = INIT_38[79:64];
	data[901] = INIT_38[95:80];
	data[902] = INIT_38[111:96];
	data[903] = INIT_38[127:112];
	data[904] = INIT_38[143:128];
	data[905] = INIT_38[159:144];
	data[906] = INIT_38[175:160];
	data[907] = INIT_38[191:176];
	data[908] = INIT_38[207:192];
	data[909] = INIT_38[223:208];
	data[910] = INIT_38[239:224];
	data[911] = INIT_38[255:240];
	data[912] = INIT_39[15:0];
	data[913] = INIT_39[31:16];
	data[914] = INIT_39[47:32];
	data[915] = INIT_39[63:48];
	data[916] = INIT_39[79:64];
	data[917] = INIT_39[95:80];
	data[918] = INIT_39[111:96];
	data[919] = INIT_39[127:112];
	data[920] = INIT_39[143:128];
	data[921] = INIT_39[159:144];
	data[922] = INIT_39[175:160];
	data[923] = INIT_39[191:176];
	data[924] = INIT_39[207:192];
	data[925] = INIT_39[223:208];
	data[926] = INIT_39[239:224];
	data[927] = INIT_39[255:240];
	data[928] = INIT_3A[15:0];
	data[929] = INIT_3A[31:16];
	data[930] = INIT_3A[47:32];
	data[931] = INIT_3A[63:48];
	data[932] = INIT_3A[79:64];
	data[933] = INIT_3A[95:80];
	data[934] = INIT_3A[111:96];
	data[935] = INIT_3A[127:112];
	data[936] = INIT_3A[143:128];
	data[937] = INIT_3A[159:144];
	data[938] = INIT_3A[175:160];
	data[939] = INIT_3A[191:176];
	data[940] = INIT_3A[207:192];
	data[941] = INIT_3A[223:208];
	data[942] = INIT_3A[239:224];
	data[943] = INIT_3A[255:240];
	data[944] = INIT_3B[15:0];
	data[945] = INIT_3B[31:16];
	data[946] = INIT_3B[47:32];
	data[947] = INIT_3B[63:48];
	data[948] = INIT_3B[79:64];
	data[949] = INIT_3B[95:80];
	data[950] = INIT_3B[111:96];
	data[951] = INIT_3B[127:112];
	data[952] = INIT_3B[143:128];
	data[953] = INIT_3B[159:144];
	data[954] = INIT_3B[175:160];
	data[955] = INIT_3B[191:176];
	data[956] = INIT_3B[207:192];
	data[957] = INIT_3B[223:208];
	data[958] = INIT_3B[239:224];
	data[959] = INIT_3B[255:240];
	data[960] = INIT_3C[15:0];
	data[961] = INIT_3C[31:16];
	data[962] = INIT_3C[47:32];
	data[963] = INIT_3C[63:48];
	data[964] = INIT_3C[79:64];
	data[965] = INIT_3C[95:80];
	data[966] = INIT_3C[111:96];
	data[967] = INIT_3C[127:112];
	data[968] = INIT_3C[143:128];
	data[969] = INIT_3C[159:144];
	data[970] = INIT_3C[175:160];
	data[971] = INIT_3C[191:176];
	data[972] = INIT_3C[207:192];
	data[973] = INIT_3C[223:208];
	data[974] = INIT_3C[239:224];
	data[975] = INIT_3C[255:240];
	data[976] = INIT_3D[15:0];
	data[977] = INIT_3D[31:16];
	data[978] = INIT_3D[47:32];
	data[979] = INIT_3D[63:48];
	data[980] = INIT_3D[79:64];
	data[981] = INIT_3D[95:80];
	data[982] = INIT_3D[111:96];
	data[983] = INIT_3D[127:112];
	data[984] = INIT_3D[143:128];
	data[985] = INIT_3D[159:144];
	data[986] = INIT_3D[175:160];
	data[987] = INIT_3D[191:176];
	data[988] = INIT_3D[207:192];
	data[989] = INIT_3D[223:208];
	data[990] = INIT_3D[239:224];
	data[991] = INIT_3D[255:240];
	data[992] = INIT_3E[15:0];
	data[993] = INIT_3E[31:16];
	data[994] = INIT_3E[47:32];
	data[995] = INIT_3E[63:48];
	data[996] = INIT_3E[79:64];
	data[997] = INIT_3E[95:80];
	data[998] = INIT_3E[111:96];
	data[999] = INIT_3E[127:112];
	data[1000] = INIT_3E[143:128];
	data[1001] = INIT_3E[159:144];
	data[1002] = INIT_3E[175:160];
	data[1003] = INIT_3E[191:176];
	data[1004] = INIT_3E[207:192];
	data[1005] = INIT_3E[223:208];
	data[1006] = INIT_3E[239:224];
	data[1007] = INIT_3E[255:240];
	data[1008] = INIT_3F[15:0];
	data[1009] = INIT_3F[31:16];
	data[1010] = INIT_3F[47:32];
	data[1011] = INIT_3F[63:48];
	data[1012] = INIT_3F[79:64];
	data[1013] = INIT_3F[95:80];
	data[1014] = INIT_3F[111:96];
	data[1015] = INIT_3F[127:112];
	data[1016] = INIT_3F[143:128];
	data[1017] = INIT_3F[159:144];
	data[1018] = INIT_3F[175:160];
	data[1019] = INIT_3F[191:176];
	data[1020] = INIT_3F[207:192];
	data[1021] = INIT_3F[223:208];
	data[1022] = INIT_3F[239:224];
	data[1023] = INIT_3F[255:240];
	parity[0] = INITP_00[1:0];
	parity[1] = INITP_00[3:2];
	parity[2] = INITP_00[5:4];
	parity[3] = INITP_00[7:6];
	parity[4] = INITP_00[9:8];
	parity[5] = INITP_00[11:10];
	parity[6] = INITP_00[13:12];
	parity[7] = INITP_00[15:14];
	parity[8] = INITP_00[17:16];
	parity[9] = INITP_00[19:18];
	parity[10] = INITP_00[21:20];
	parity[11] = INITP_00[23:22];
	parity[12] = INITP_00[25:24];
	parity[13] = INITP_00[27:26];
	parity[14] = INITP_00[29:28];
	parity[15] = INITP_00[31:30];
	parity[16] = INITP_00[33:32];
	parity[17] = INITP_00[35:34];
	parity[18] = INITP_00[37:36];
	parity[19] = INITP_00[39:38];
	parity[20] = INITP_00[41:40];
	parity[21] = INITP_00[43:42];
	parity[22] = INITP_00[45:44];
	parity[23] = INITP_00[47:46];
	parity[24] = INITP_00[49:48];
	parity[25] = INITP_00[51:50];
	parity[26] = INITP_00[53:52];
	parity[27] = INITP_00[55:54];
	parity[28] = INITP_00[57:56];
	parity[29] = INITP_00[59:58];
	parity[30] = INITP_00[61:60];
	parity[31] = INITP_00[63:62];
	parity[32] = INITP_00[65:64];
	parity[33] = INITP_00[67:66];
	parity[34] = INITP_00[69:68];
	parity[35] = INITP_00[71:70];
	parity[36] = INITP_00[73:72];
	parity[37] = INITP_00[75:74];
	parity[38] = INITP_00[77:76];
	parity[39] = INITP_00[79:78];
	parity[40] = INITP_00[81:80];
	parity[41] = INITP_00[83:82];
	parity[42] = INITP_00[85:84];
	parity[43] = INITP_00[87:86];
	parity[44] = INITP_00[89:88];
	parity[45] = INITP_00[91:90];
	parity[46] = INITP_00[93:92];
	parity[47] = INITP_00[95:94];
	parity[48] = INITP_00[97:96];
	parity[49] = INITP_00[99:98];
	parity[50] = INITP_00[101:100];
	parity[51] = INITP_00[103:102];
	parity[52] = INITP_00[105:104];
	parity[53] = INITP_00[107:106];
	parity[54] = INITP_00[109:108];
	parity[55] = INITP_00[111:110];
	parity[56] = INITP_00[113:112];
	parity[57] = INITP_00[115:114];
	parity[58] = INITP_00[117:116];
	parity[59] = INITP_00[119:118];
	parity[60] = INITP_00[121:120];
	parity[61] = INITP_00[123:122];
	parity[62] = INITP_00[125:124];
	parity[63] = INITP_00[127:126];
	parity[64] = INITP_00[129:128];
	parity[65] = INITP_00[131:130];
	parity[66] = INITP_00[133:132];
	parity[67] = INITP_00[135:134];
	parity[68] = INITP_00[137:136];
	parity[69] = INITP_00[139:138];
	parity[70] = INITP_00[141:140];
	parity[71] = INITP_00[143:142];
	parity[72] = INITP_00[145:144];
	parity[73] = INITP_00[147:146];
	parity[74] = INITP_00[149:148];
	parity[75] = INITP_00[151:150];
	parity[76] = INITP_00[153:152];
	parity[77] = INITP_00[155:154];
	parity[78] = INITP_00[157:156];
	parity[79] = INITP_00[159:158];
	parity[80] = INITP_00[161:160];
	parity[81] = INITP_00[163:162];
	parity[82] = INITP_00[165:164];
	parity[83] = INITP_00[167:166];
	parity[84] = INITP_00[169:168];
	parity[85] = INITP_00[171:170];
	parity[86] = INITP_00[173:172];
	parity[87] = INITP_00[175:174];
	parity[88] = INITP_00[177:176];
	parity[89] = INITP_00[179:178];
	parity[90] = INITP_00[181:180];
	parity[91] = INITP_00[183:182];
	parity[92] = INITP_00[185:184];
	parity[93] = INITP_00[187:186];
	parity[94] = INITP_00[189:188];
	parity[95] = INITP_00[191:190];
	parity[96] = INITP_00[193:192];
	parity[97] = INITP_00[195:194];
	parity[98] = INITP_00[197:196];
	parity[99] = INITP_00[199:198];
	parity[100] = INITP_00[201:200];
	parity[101] = INITP_00[203:202];
	parity[102] = INITP_00[205:204];
	parity[103] = INITP_00[207:206];
	parity[104] = INITP_00[209:208];
	parity[105] = INITP_00[211:210];
	parity[106] = INITP_00[213:212];
	parity[107] = INITP_00[215:214];
	parity[108] = INITP_00[217:216];
	parity[109] = INITP_00[219:218];
	parity[110] = INITP_00[221:220];
	parity[111] = INITP_00[223:222];
	parity[112] = INITP_00[225:224];
	parity[113] = INITP_00[227:226];
	parity[114] = INITP_00[229:228];
	parity[115] = INITP_00[231:230];
	parity[116] = INITP_00[233:232];
	parity[117] = INITP_00[235:234];
	parity[118] = INITP_00[237:236];
	parity[119] = INITP_00[239:238];
	parity[120] = INITP_00[241:240];
	parity[121] = INITP_00[243:242];
	parity[122] = INITP_00[245:244];
	parity[123] = INITP_00[247:246];
	parity[124] = INITP_00[249:248];
	parity[125] = INITP_00[251:250];
	parity[126] = INITP_00[253:252];
	parity[127] = INITP_00[255:254];
	parity[128] = INITP_01[1:0];
	parity[129] = INITP_01[3:2];
	parity[130] = INITP_01[5:4];
	parity[131] = INITP_01[7:6];
	parity[132] = INITP_01[9:8];
	parity[133] = INITP_01[11:10];
	parity[134] = INITP_01[13:12];
	parity[135] = INITP_01[15:14];
	parity[136] = INITP_01[17:16];
	parity[137] = INITP_01[19:18];
	parity[138] = INITP_01[21:20];
	parity[139] = INITP_01[23:22];
	parity[140] = INITP_01[25:24];
	parity[141] = INITP_01[27:26];
	parity[142] = INITP_01[29:28];
	parity[143] = INITP_01[31:30];
	parity[144] = INITP_01[33:32];
	parity[145] = INITP_01[35:34];
	parity[146] = INITP_01[37:36];
	parity[147] = INITP_01[39:38];
	parity[148] = INITP_01[41:40];
	parity[149] = INITP_01[43:42];
	parity[150] = INITP_01[45:44];
	parity[151] = INITP_01[47:46];
	parity[152] = INITP_01[49:48];
	parity[153] = INITP_01[51:50];
	parity[154] = INITP_01[53:52];
	parity[155] = INITP_01[55:54];
	parity[156] = INITP_01[57:56];
	parity[157] = INITP_01[59:58];
	parity[158] = INITP_01[61:60];
	parity[159] = INITP_01[63:62];
	parity[160] = INITP_01[65:64];
	parity[161] = INITP_01[67:66];
	parity[162] = INITP_01[69:68];
	parity[163] = INITP_01[71:70];
	parity[164] = INITP_01[73:72];
	parity[165] = INITP_01[75:74];
	parity[166] = INITP_01[77:76];
	parity[167] = INITP_01[79:78];
	parity[168] = INITP_01[81:80];
	parity[169] = INITP_01[83:82];
	parity[170] = INITP_01[85:84];
	parity[171] = INITP_01[87:86];
	parity[172] = INITP_01[89:88];
	parity[173] = INITP_01[91:90];
	parity[174] = INITP_01[93:92];
	parity[175] = INITP_01[95:94];
	parity[176] = INITP_01[97:96];
	parity[177] = INITP_01[99:98];
	parity[178] = INITP_01[101:100];
	parity[179] = INITP_01[103:102];
	parity[180] = INITP_01[105:104];
	parity[181] = INITP_01[107:106];
	parity[182] = INITP_01[109:108];
	parity[183] = INITP_01[111:110];
	parity[184] = INITP_01[113:112];
	parity[185] = INITP_01[115:114];
	parity[186] = INITP_01[117:116];
	parity[187] = INITP_01[119:118];
	parity[188] = INITP_01[121:120];
	parity[189] = INITP_01[123:122];
	parity[190] = INITP_01[125:124];
	parity[191] = INITP_01[127:126];
	parity[192] = INITP_01[129:128];
	parity[193] = INITP_01[131:130];
	parity[194] = INITP_01[133:132];
	parity[195] = INITP_01[135:134];
	parity[196] = INITP_01[137:136];
	parity[197] = INITP_01[139:138];
	parity[198] = INITP_01[141:140];
	parity[199] = INITP_01[143:142];
	parity[200] = INITP_01[145:144];
	parity[201] = INITP_01[147:146];
	parity[202] = INITP_01[149:148];
	parity[203] = INITP_01[151:150];
	parity[204] = INITP_01[153:152];
	parity[205] = INITP_01[155:154];
	parity[206] = INITP_01[157:156];
	parity[207] = INITP_01[159:158];
	parity[208] = INITP_01[161:160];
	parity[209] = INITP_01[163:162];
	parity[210] = INITP_01[165:164];
	parity[211] = INITP_01[167:166];
	parity[212] = INITP_01[169:168];
	parity[213] = INITP_01[171:170];
	parity[214] = INITP_01[173:172];
	parity[215] = INITP_01[175:174];
	parity[216] = INITP_01[177:176];
	parity[217] = INITP_01[179:178];
	parity[218] = INITP_01[181:180];
	parity[219] = INITP_01[183:182];
	parity[220] = INITP_01[185:184];
	parity[221] = INITP_01[187:186];
	parity[222] = INITP_01[189:188];
	parity[223] = INITP_01[191:190];
	parity[224] = INITP_01[193:192];
	parity[225] = INITP_01[195:194];
	parity[226] = INITP_01[197:196];
	parity[227] = INITP_01[199:198];
	parity[228] = INITP_01[201:200];
	parity[229] = INITP_01[203:202];
	parity[230] = INITP_01[205:204];
	parity[231] = INITP_01[207:206];
	parity[232] = INITP_01[209:208];
	parity[233] = INITP_01[211:210];
	parity[234] = INITP_01[213:212];
	parity[235] = INITP_01[215:214];
	parity[236] = INITP_01[217:216];
	parity[237] = INITP_01[219:218];
	parity[238] = INITP_01[221:220];
	parity[239] = INITP_01[223:222];
	parity[240] = INITP_01[225:224];
	parity[241] = INITP_01[227:226];
	parity[242] = INITP_01[229:228];
	parity[243] = INITP_01[231:230];
	parity[244] = INITP_01[233:232];
	parity[245] = INITP_01[235:234];
	parity[246] = INITP_01[237:236];
	parity[247] = INITP_01[239:238];
	parity[248] = INITP_01[241:240];
	parity[249] = INITP_01[243:242];
	parity[250] = INITP_01[245:244];
	parity[251] = INITP_01[247:246];
	parity[252] = INITP_01[249:248];
	parity[253] = INITP_01[251:250];
	parity[254] = INITP_01[253:252];
	parity[255] = INITP_01[255:254];
	parity[256] = INITP_02[1:0];
	parity[257] = INITP_02[3:2];
	parity[258] = INITP_02[5:4];
	parity[259] = INITP_02[7:6];
	parity[260] = INITP_02[9:8];
	parity[261] = INITP_02[11:10];
	parity[262] = INITP_02[13:12];
	parity[263] = INITP_02[15:14];
	parity[264] = INITP_02[17:16];
	parity[265] = INITP_02[19:18];
	parity[266] = INITP_02[21:20];
	parity[267] = INITP_02[23:22];
	parity[268] = INITP_02[25:24];
	parity[269] = INITP_02[27:26];
	parity[270] = INITP_02[29:28];
	parity[271] = INITP_02[31:30];
	parity[272] = INITP_02[33:32];
	parity[273] = INITP_02[35:34];
	parity[274] = INITP_02[37:36];
	parity[275] = INITP_02[39:38];
	parity[276] = INITP_02[41:40];
	parity[277] = INITP_02[43:42];
	parity[278] = INITP_02[45:44];
	parity[279] = INITP_02[47:46];
	parity[280] = INITP_02[49:48];
	parity[281] = INITP_02[51:50];
	parity[282] = INITP_02[53:52];
	parity[283] = INITP_02[55:54];
	parity[284] = INITP_02[57:56];
	parity[285] = INITP_02[59:58];
	parity[286] = INITP_02[61:60];
	parity[287] = INITP_02[63:62];
	parity[288] = INITP_02[65:64];
	parity[289] = INITP_02[67:66];
	parity[290] = INITP_02[69:68];
	parity[291] = INITP_02[71:70];
	parity[292] = INITP_02[73:72];
	parity[293] = INITP_02[75:74];
	parity[294] = INITP_02[77:76];
	parity[295] = INITP_02[79:78];
	parity[296] = INITP_02[81:80];
	parity[297] = INITP_02[83:82];
	parity[298] = INITP_02[85:84];
	parity[299] = INITP_02[87:86];
	parity[300] = INITP_02[89:88];
	parity[301] = INITP_02[91:90];
	parity[302] = INITP_02[93:92];
	parity[303] = INITP_02[95:94];
	parity[304] = INITP_02[97:96];
	parity[305] = INITP_02[99:98];
	parity[306] = INITP_02[101:100];
	parity[307] = INITP_02[103:102];
	parity[308] = INITP_02[105:104];
	parity[309] = INITP_02[107:106];
	parity[310] = INITP_02[109:108];
	parity[311] = INITP_02[111:110];
	parity[312] = INITP_02[113:112];
	parity[313] = INITP_02[115:114];
	parity[314] = INITP_02[117:116];
	parity[315] = INITP_02[119:118];
	parity[316] = INITP_02[121:120];
	parity[317] = INITP_02[123:122];
	parity[318] = INITP_02[125:124];
	parity[319] = INITP_02[127:126];
	parity[320] = INITP_02[129:128];
	parity[321] = INITP_02[131:130];
	parity[322] = INITP_02[133:132];
	parity[323] = INITP_02[135:134];
	parity[324] = INITP_02[137:136];
	parity[325] = INITP_02[139:138];
	parity[326] = INITP_02[141:140];
	parity[327] = INITP_02[143:142];
	parity[328] = INITP_02[145:144];
	parity[329] = INITP_02[147:146];
	parity[330] = INITP_02[149:148];
	parity[331] = INITP_02[151:150];
	parity[332] = INITP_02[153:152];
	parity[333] = INITP_02[155:154];
	parity[334] = INITP_02[157:156];
	parity[335] = INITP_02[159:158];
	parity[336] = INITP_02[161:160];
	parity[337] = INITP_02[163:162];
	parity[338] = INITP_02[165:164];
	parity[339] = INITP_02[167:166];
	parity[340] = INITP_02[169:168];
	parity[341] = INITP_02[171:170];
	parity[342] = INITP_02[173:172];
	parity[343] = INITP_02[175:174];
	parity[344] = INITP_02[177:176];
	parity[345] = INITP_02[179:178];
	parity[346] = INITP_02[181:180];
	parity[347] = INITP_02[183:182];
	parity[348] = INITP_02[185:184];
	parity[349] = INITP_02[187:186];
	parity[350] = INITP_02[189:188];
	parity[351] = INITP_02[191:190];
	parity[352] = INITP_02[193:192];
	parity[353] = INITP_02[195:194];
	parity[354] = INITP_02[197:196];
	parity[355] = INITP_02[199:198];
	parity[356] = INITP_02[201:200];
	parity[357] = INITP_02[203:202];
	parity[358] = INITP_02[205:204];
	parity[359] = INITP_02[207:206];
	parity[360] = INITP_02[209:208];
	parity[361] = INITP_02[211:210];
	parity[362] = INITP_02[213:212];
	parity[363] = INITP_02[215:214];
	parity[364] = INITP_02[217:216];
	parity[365] = INITP_02[219:218];
	parity[366] = INITP_02[221:220];
	parity[367] = INITP_02[223:222];
	parity[368] = INITP_02[225:224];
	parity[369] = INITP_02[227:226];
	parity[370] = INITP_02[229:228];
	parity[371] = INITP_02[231:230];
	parity[372] = INITP_02[233:232];
	parity[373] = INITP_02[235:234];
	parity[374] = INITP_02[237:236];
	parity[375] = INITP_02[239:238];
	parity[376] = INITP_02[241:240];
	parity[377] = INITP_02[243:242];
	parity[378] = INITP_02[245:244];
	parity[379] = INITP_02[247:246];
	parity[380] = INITP_02[249:248];
	parity[381] = INITP_02[251:250];
	parity[382] = INITP_02[253:252];
	parity[383] = INITP_02[255:254];
	parity[384] = INITP_03[1:0];
	parity[385] = INITP_03[3:2];
	parity[386] = INITP_03[5:4];
	parity[387] = INITP_03[7:6];
	parity[388] = INITP_03[9:8];
	parity[389] = INITP_03[11:10];
	parity[390] = INITP_03[13:12];
	parity[391] = INITP_03[15:14];
	parity[392] = INITP_03[17:16];
	parity[393] = INITP_03[19:18];
	parity[394] = INITP_03[21:20];
	parity[395] = INITP_03[23:22];
	parity[396] = INITP_03[25:24];
	parity[397] = INITP_03[27:26];
	parity[398] = INITP_03[29:28];
	parity[399] = INITP_03[31:30];
	parity[400] = INITP_03[33:32];
	parity[401] = INITP_03[35:34];
	parity[402] = INITP_03[37:36];
	parity[403] = INITP_03[39:38];
	parity[404] = INITP_03[41:40];
	parity[405] = INITP_03[43:42];
	parity[406] = INITP_03[45:44];
	parity[407] = INITP_03[47:46];
	parity[408] = INITP_03[49:48];
	parity[409] = INITP_03[51:50];
	parity[410] = INITP_03[53:52];
	parity[411] = INITP_03[55:54];
	parity[412] = INITP_03[57:56];
	parity[413] = INITP_03[59:58];
	parity[414] = INITP_03[61:60];
	parity[415] = INITP_03[63:62];
	parity[416] = INITP_03[65:64];
	parity[417] = INITP_03[67:66];
	parity[418] = INITP_03[69:68];
	parity[419] = INITP_03[71:70];
	parity[420] = INITP_03[73:72];
	parity[421] = INITP_03[75:74];
	parity[422] = INITP_03[77:76];
	parity[423] = INITP_03[79:78];
	parity[424] = INITP_03[81:80];
	parity[425] = INITP_03[83:82];
	parity[426] = INITP_03[85:84];
	parity[427] = INITP_03[87:86];
	parity[428] = INITP_03[89:88];
	parity[429] = INITP_03[91:90];
	parity[430] = INITP_03[93:92];
	parity[431] = INITP_03[95:94];
	parity[432] = INITP_03[97:96];
	parity[433] = INITP_03[99:98];
	parity[434] = INITP_03[101:100];
	parity[435] = INITP_03[103:102];
	parity[436] = INITP_03[105:104];
	parity[437] = INITP_03[107:106];
	parity[438] = INITP_03[109:108];
	parity[439] = INITP_03[111:110];
	parity[440] = INITP_03[113:112];
	parity[441] = INITP_03[115:114];
	parity[442] = INITP_03[117:116];
	parity[443] = INITP_03[119:118];
	parity[444] = INITP_03[121:120];
	parity[445] = INITP_03[123:122];
	parity[446] = INITP_03[125:124];
	parity[447] = INITP_03[127:126];
	parity[448] = INITP_03[129:128];
	parity[449] = INITP_03[131:130];
	parity[450] = INITP_03[133:132];
	parity[451] = INITP_03[135:134];
	parity[452] = INITP_03[137:136];
	parity[453] = INITP_03[139:138];
	parity[454] = INITP_03[141:140];
	parity[455] = INITP_03[143:142];
	parity[456] = INITP_03[145:144];
	parity[457] = INITP_03[147:146];
	parity[458] = INITP_03[149:148];
	parity[459] = INITP_03[151:150];
	parity[460] = INITP_03[153:152];
	parity[461] = INITP_03[155:154];
	parity[462] = INITP_03[157:156];
	parity[463] = INITP_03[159:158];
	parity[464] = INITP_03[161:160];
	parity[465] = INITP_03[163:162];
	parity[466] = INITP_03[165:164];
	parity[467] = INITP_03[167:166];
	parity[468] = INITP_03[169:168];
	parity[469] = INITP_03[171:170];
	parity[470] = INITP_03[173:172];
	parity[471] = INITP_03[175:174];
	parity[472] = INITP_03[177:176];
	parity[473] = INITP_03[179:178];
	parity[474] = INITP_03[181:180];
	parity[475] = INITP_03[183:182];
	parity[476] = INITP_03[185:184];
	parity[477] = INITP_03[187:186];
	parity[478] = INITP_03[189:188];
	parity[479] = INITP_03[191:190];
	parity[480] = INITP_03[193:192];
	parity[481] = INITP_03[195:194];
	parity[482] = INITP_03[197:196];
	parity[483] = INITP_03[199:198];
	parity[484] = INITP_03[201:200];
	parity[485] = INITP_03[203:202];
	parity[486] = INITP_03[205:204];
	parity[487] = INITP_03[207:206];
	parity[488] = INITP_03[209:208];
	parity[489] = INITP_03[211:210];
	parity[490] = INITP_03[213:212];
	parity[491] = INITP_03[215:214];
	parity[492] = INITP_03[217:216];
	parity[493] = INITP_03[219:218];
	parity[494] = INITP_03[221:220];
	parity[495] = INITP_03[223:222];
	parity[496] = INITP_03[225:224];
	parity[497] = INITP_03[227:226];
	parity[498] = INITP_03[229:228];
	parity[499] = INITP_03[231:230];
	parity[500] = INITP_03[233:232];
	parity[501] = INITP_03[235:234];
	parity[502] = INITP_03[237:236];
	parity[503] = INITP_03[239:238];
	parity[504] = INITP_03[241:240];
	parity[505] = INITP_03[243:242];
	parity[506] = INITP_03[245:244];
	parity[507] = INITP_03[247:246];
	parity[508] = INITP_03[249:248];
	parity[509] = INITP_03[251:250];
	parity[510] = INITP_03[253:252];
	parity[511] = INITP_03[255:254];
	parity[512] = INITP_04[1:0];
	parity[513] = INITP_04[3:2];
	parity[514] = INITP_04[5:4];
	parity[515] = INITP_04[7:6];
	parity[516] = INITP_04[9:8];
	parity[517] = INITP_04[11:10];
	parity[518] = INITP_04[13:12];
	parity[519] = INITP_04[15:14];
	parity[520] = INITP_04[17:16];
	parity[521] = INITP_04[19:18];
	parity[522] = INITP_04[21:20];
	parity[523] = INITP_04[23:22];
	parity[524] = INITP_04[25:24];
	parity[525] = INITP_04[27:26];
	parity[526] = INITP_04[29:28];
	parity[527] = INITP_04[31:30];
	parity[528] = INITP_04[33:32];
	parity[529] = INITP_04[35:34];
	parity[530] = INITP_04[37:36];
	parity[531] = INITP_04[39:38];
	parity[532] = INITP_04[41:40];
	parity[533] = INITP_04[43:42];
	parity[534] = INITP_04[45:44];
	parity[535] = INITP_04[47:46];
	parity[536] = INITP_04[49:48];
	parity[537] = INITP_04[51:50];
	parity[538] = INITP_04[53:52];
	parity[539] = INITP_04[55:54];
	parity[540] = INITP_04[57:56];
	parity[541] = INITP_04[59:58];
	parity[542] = INITP_04[61:60];
	parity[543] = INITP_04[63:62];
	parity[544] = INITP_04[65:64];
	parity[545] = INITP_04[67:66];
	parity[546] = INITP_04[69:68];
	parity[547] = INITP_04[71:70];
	parity[548] = INITP_04[73:72];
	parity[549] = INITP_04[75:74];
	parity[550] = INITP_04[77:76];
	parity[551] = INITP_04[79:78];
	parity[552] = INITP_04[81:80];
	parity[553] = INITP_04[83:82];
	parity[554] = INITP_04[85:84];
	parity[555] = INITP_04[87:86];
	parity[556] = INITP_04[89:88];
	parity[557] = INITP_04[91:90];
	parity[558] = INITP_04[93:92];
	parity[559] = INITP_04[95:94];
	parity[560] = INITP_04[97:96];
	parity[561] = INITP_04[99:98];
	parity[562] = INITP_04[101:100];
	parity[563] = INITP_04[103:102];
	parity[564] = INITP_04[105:104];
	parity[565] = INITP_04[107:106];
	parity[566] = INITP_04[109:108];
	parity[567] = INITP_04[111:110];
	parity[568] = INITP_04[113:112];
	parity[569] = INITP_04[115:114];
	parity[570] = INITP_04[117:116];
	parity[571] = INITP_04[119:118];
	parity[572] = INITP_04[121:120];
	parity[573] = INITP_04[123:122];
	parity[574] = INITP_04[125:124];
	parity[575] = INITP_04[127:126];
	parity[576] = INITP_04[129:128];
	parity[577] = INITP_04[131:130];
	parity[578] = INITP_04[133:132];
	parity[579] = INITP_04[135:134];
	parity[580] = INITP_04[137:136];
	parity[581] = INITP_04[139:138];
	parity[582] = INITP_04[141:140];
	parity[583] = INITP_04[143:142];
	parity[584] = INITP_04[145:144];
	parity[585] = INITP_04[147:146];
	parity[586] = INITP_04[149:148];
	parity[587] = INITP_04[151:150];
	parity[588] = INITP_04[153:152];
	parity[589] = INITP_04[155:154];
	parity[590] = INITP_04[157:156];
	parity[591] = INITP_04[159:158];
	parity[592] = INITP_04[161:160];
	parity[593] = INITP_04[163:162];
	parity[594] = INITP_04[165:164];
	parity[595] = INITP_04[167:166];
	parity[596] = INITP_04[169:168];
	parity[597] = INITP_04[171:170];
	parity[598] = INITP_04[173:172];
	parity[599] = INITP_04[175:174];
	parity[600] = INITP_04[177:176];
	parity[601] = INITP_04[179:178];
	parity[602] = INITP_04[181:180];
	parity[603] = INITP_04[183:182];
	parity[604] = INITP_04[185:184];
	parity[605] = INITP_04[187:186];
	parity[606] = INITP_04[189:188];
	parity[607] = INITP_04[191:190];
	parity[608] = INITP_04[193:192];
	parity[609] = INITP_04[195:194];
	parity[610] = INITP_04[197:196];
	parity[611] = INITP_04[199:198];
	parity[612] = INITP_04[201:200];
	parity[613] = INITP_04[203:202];
	parity[614] = INITP_04[205:204];
	parity[615] = INITP_04[207:206];
	parity[616] = INITP_04[209:208];
	parity[617] = INITP_04[211:210];
	parity[618] = INITP_04[213:212];
	parity[619] = INITP_04[215:214];
	parity[620] = INITP_04[217:216];
	parity[621] = INITP_04[219:218];
	parity[622] = INITP_04[221:220];
	parity[623] = INITP_04[223:222];
	parity[624] = INITP_04[225:224];
	parity[625] = INITP_04[227:226];
	parity[626] = INITP_04[229:228];
	parity[627] = INITP_04[231:230];
	parity[628] = INITP_04[233:232];
	parity[629] = INITP_04[235:234];
	parity[630] = INITP_04[237:236];
	parity[631] = INITP_04[239:238];
	parity[632] = INITP_04[241:240];
	parity[633] = INITP_04[243:242];
	parity[634] = INITP_04[245:244];
	parity[635] = INITP_04[247:246];
	parity[636] = INITP_04[249:248];
	parity[637] = INITP_04[251:250];
	parity[638] = INITP_04[253:252];
	parity[639] = INITP_04[255:254];
	parity[640] = INITP_05[1:0];
	parity[641] = INITP_05[3:2];
	parity[642] = INITP_05[5:4];
	parity[643] = INITP_05[7:6];
	parity[644] = INITP_05[9:8];
	parity[645] = INITP_05[11:10];
	parity[646] = INITP_05[13:12];
	parity[647] = INITP_05[15:14];
	parity[648] = INITP_05[17:16];
	parity[649] = INITP_05[19:18];
	parity[650] = INITP_05[21:20];
	parity[651] = INITP_05[23:22];
	parity[652] = INITP_05[25:24];
	parity[653] = INITP_05[27:26];
	parity[654] = INITP_05[29:28];
	parity[655] = INITP_05[31:30];
	parity[656] = INITP_05[33:32];
	parity[657] = INITP_05[35:34];
	parity[658] = INITP_05[37:36];
	parity[659] = INITP_05[39:38];
	parity[660] = INITP_05[41:40];
	parity[661] = INITP_05[43:42];
	parity[662] = INITP_05[45:44];
	parity[663] = INITP_05[47:46];
	parity[664] = INITP_05[49:48];
	parity[665] = INITP_05[51:50];
	parity[666] = INITP_05[53:52];
	parity[667] = INITP_05[55:54];
	parity[668] = INITP_05[57:56];
	parity[669] = INITP_05[59:58];
	parity[670] = INITP_05[61:60];
	parity[671] = INITP_05[63:62];
	parity[672] = INITP_05[65:64];
	parity[673] = INITP_05[67:66];
	parity[674] = INITP_05[69:68];
	parity[675] = INITP_05[71:70];
	parity[676] = INITP_05[73:72];
	parity[677] = INITP_05[75:74];
	parity[678] = INITP_05[77:76];
	parity[679] = INITP_05[79:78];
	parity[680] = INITP_05[81:80];
	parity[681] = INITP_05[83:82];
	parity[682] = INITP_05[85:84];
	parity[683] = INITP_05[87:86];
	parity[684] = INITP_05[89:88];
	parity[685] = INITP_05[91:90];
	parity[686] = INITP_05[93:92];
	parity[687] = INITP_05[95:94];
	parity[688] = INITP_05[97:96];
	parity[689] = INITP_05[99:98];
	parity[690] = INITP_05[101:100];
	parity[691] = INITP_05[103:102];
	parity[692] = INITP_05[105:104];
	parity[693] = INITP_05[107:106];
	parity[694] = INITP_05[109:108];
	parity[695] = INITP_05[111:110];
	parity[696] = INITP_05[113:112];
	parity[697] = INITP_05[115:114];
	parity[698] = INITP_05[117:116];
	parity[699] = INITP_05[119:118];
	parity[700] = INITP_05[121:120];
	parity[701] = INITP_05[123:122];
	parity[702] = INITP_05[125:124];
	parity[703] = INITP_05[127:126];
	parity[704] = INITP_05[129:128];
	parity[705] = INITP_05[131:130];
	parity[706] = INITP_05[133:132];
	parity[707] = INITP_05[135:134];
	parity[708] = INITP_05[137:136];
	parity[709] = INITP_05[139:138];
	parity[710] = INITP_05[141:140];
	parity[711] = INITP_05[143:142];
	parity[712] = INITP_05[145:144];
	parity[713] = INITP_05[147:146];
	parity[714] = INITP_05[149:148];
	parity[715] = INITP_05[151:150];
	parity[716] = INITP_05[153:152];
	parity[717] = INITP_05[155:154];
	parity[718] = INITP_05[157:156];
	parity[719] = INITP_05[159:158];
	parity[720] = INITP_05[161:160];
	parity[721] = INITP_05[163:162];
	parity[722] = INITP_05[165:164];
	parity[723] = INITP_05[167:166];
	parity[724] = INITP_05[169:168];
	parity[725] = INITP_05[171:170];
	parity[726] = INITP_05[173:172];
	parity[727] = INITP_05[175:174];
	parity[728] = INITP_05[177:176];
	parity[729] = INITP_05[179:178];
	parity[730] = INITP_05[181:180];
	parity[731] = INITP_05[183:182];
	parity[732] = INITP_05[185:184];
	parity[733] = INITP_05[187:186];
	parity[734] = INITP_05[189:188];
	parity[735] = INITP_05[191:190];
	parity[736] = INITP_05[193:192];
	parity[737] = INITP_05[195:194];
	parity[738] = INITP_05[197:196];
	parity[739] = INITP_05[199:198];
	parity[740] = INITP_05[201:200];
	parity[741] = INITP_05[203:202];
	parity[742] = INITP_05[205:204];
	parity[743] = INITP_05[207:206];
	parity[744] = INITP_05[209:208];
	parity[745] = INITP_05[211:210];
	parity[746] = INITP_05[213:212];
	parity[747] = INITP_05[215:214];
	parity[748] = INITP_05[217:216];
	parity[749] = INITP_05[219:218];
	parity[750] = INITP_05[221:220];
	parity[751] = INITP_05[223:222];
	parity[752] = INITP_05[225:224];
	parity[753] = INITP_05[227:226];
	parity[754] = INITP_05[229:228];
	parity[755] = INITP_05[231:230];
	parity[756] = INITP_05[233:232];
	parity[757] = INITP_05[235:234];
	parity[758] = INITP_05[237:236];
	parity[759] = INITP_05[239:238];
	parity[760] = INITP_05[241:240];
	parity[761] = INITP_05[243:242];
	parity[762] = INITP_05[245:244];
	parity[763] = INITP_05[247:246];
	parity[764] = INITP_05[249:248];
	parity[765] = INITP_05[251:250];
	parity[766] = INITP_05[253:252];
	parity[767] = INITP_05[255:254];
	parity[768] = INITP_06[1:0];
	parity[769] = INITP_06[3:2];
	parity[770] = INITP_06[5:4];
	parity[771] = INITP_06[7:6];
	parity[772] = INITP_06[9:8];
	parity[773] = INITP_06[11:10];
	parity[774] = INITP_06[13:12];
	parity[775] = INITP_06[15:14];
	parity[776] = INITP_06[17:16];
	parity[777] = INITP_06[19:18];
	parity[778] = INITP_06[21:20];
	parity[779] = INITP_06[23:22];
	parity[780] = INITP_06[25:24];
	parity[781] = INITP_06[27:26];
	parity[782] = INITP_06[29:28];
	parity[783] = INITP_06[31:30];
	parity[784] = INITP_06[33:32];
	parity[785] = INITP_06[35:34];
	parity[786] = INITP_06[37:36];
	parity[787] = INITP_06[39:38];
	parity[788] = INITP_06[41:40];
	parity[789] = INITP_06[43:42];
	parity[790] = INITP_06[45:44];
	parity[791] = INITP_06[47:46];
	parity[792] = INITP_06[49:48];
	parity[793] = INITP_06[51:50];
	parity[794] = INITP_06[53:52];
	parity[795] = INITP_06[55:54];
	parity[796] = INITP_06[57:56];
	parity[797] = INITP_06[59:58];
	parity[798] = INITP_06[61:60];
	parity[799] = INITP_06[63:62];
	parity[800] = INITP_06[65:64];
	parity[801] = INITP_06[67:66];
	parity[802] = INITP_06[69:68];
	parity[803] = INITP_06[71:70];
	parity[804] = INITP_06[73:72];
	parity[805] = INITP_06[75:74];
	parity[806] = INITP_06[77:76];
	parity[807] = INITP_06[79:78];
	parity[808] = INITP_06[81:80];
	parity[809] = INITP_06[83:82];
	parity[810] = INITP_06[85:84];
	parity[811] = INITP_06[87:86];
	parity[812] = INITP_06[89:88];
	parity[813] = INITP_06[91:90];
	parity[814] = INITP_06[93:92];
	parity[815] = INITP_06[95:94];
	parity[816] = INITP_06[97:96];
	parity[817] = INITP_06[99:98];
	parity[818] = INITP_06[101:100];
	parity[819] = INITP_06[103:102];
	parity[820] = INITP_06[105:104];
	parity[821] = INITP_06[107:106];
	parity[822] = INITP_06[109:108];
	parity[823] = INITP_06[111:110];
	parity[824] = INITP_06[113:112];
	parity[825] = INITP_06[115:114];
	parity[826] = INITP_06[117:116];
	parity[827] = INITP_06[119:118];
	parity[828] = INITP_06[121:120];
	parity[829] = INITP_06[123:122];
	parity[830] = INITP_06[125:124];
	parity[831] = INITP_06[127:126];
	parity[832] = INITP_06[129:128];
	parity[833] = INITP_06[131:130];
	parity[834] = INITP_06[133:132];
	parity[835] = INITP_06[135:134];
	parity[836] = INITP_06[137:136];
	parity[837] = INITP_06[139:138];
	parity[838] = INITP_06[141:140];
	parity[839] = INITP_06[143:142];
	parity[840] = INITP_06[145:144];
	parity[841] = INITP_06[147:146];
	parity[842] = INITP_06[149:148];
	parity[843] = INITP_06[151:150];
	parity[844] = INITP_06[153:152];
	parity[845] = INITP_06[155:154];
	parity[846] = INITP_06[157:156];
	parity[847] = INITP_06[159:158];
	parity[848] = INITP_06[161:160];
	parity[849] = INITP_06[163:162];
	parity[850] = INITP_06[165:164];
	parity[851] = INITP_06[167:166];
	parity[852] = INITP_06[169:168];
	parity[853] = INITP_06[171:170];
	parity[854] = INITP_06[173:172];
	parity[855] = INITP_06[175:174];
	parity[856] = INITP_06[177:176];
	parity[857] = INITP_06[179:178];
	parity[858] = INITP_06[181:180];
	parity[859] = INITP_06[183:182];
	parity[860] = INITP_06[185:184];
	parity[861] = INITP_06[187:186];
	parity[862] = INITP_06[189:188];
	parity[863] = INITP_06[191:190];
	parity[864] = INITP_06[193:192];
	parity[865] = INITP_06[195:194];
	parity[866] = INITP_06[197:196];
	parity[867] = INITP_06[199:198];
	parity[868] = INITP_06[201:200];
	parity[869] = INITP_06[203:202];
	parity[870] = INITP_06[205:204];
	parity[871] = INITP_06[207:206];
	parity[872] = INITP_06[209:208];
	parity[873] = INITP_06[211:210];
	parity[874] = INITP_06[213:212];
	parity[875] = INITP_06[215:214];
	parity[876] = INITP_06[217:216];
	parity[877] = INITP_06[219:218];
	parity[878] = INITP_06[221:220];
	parity[879] = INITP_06[223:222];
	parity[880] = INITP_06[225:224];
	parity[881] = INITP_06[227:226];
	parity[882] = INITP_06[229:228];
	parity[883] = INITP_06[231:230];
	parity[884] = INITP_06[233:232];
	parity[885] = INITP_06[235:234];
	parity[886] = INITP_06[237:236];
	parity[887] = INITP_06[239:238];
	parity[888] = INITP_06[241:240];
	parity[889] = INITP_06[243:242];
	parity[890] = INITP_06[245:244];
	parity[891] = INITP_06[247:246];
	parity[892] = INITP_06[249:248];
	parity[893] = INITP_06[251:250];
	parity[894] = INITP_06[253:252];
	parity[895] = INITP_06[255:254];
	parity[896] = INITP_07[1:0];
	parity[897] = INITP_07[3:2];
	parity[898] = INITP_07[5:4];
	parity[899] = INITP_07[7:6];
	parity[900] = INITP_07[9:8];
	parity[901] = INITP_07[11:10];
	parity[902] = INITP_07[13:12];
	parity[903] = INITP_07[15:14];
	parity[904] = INITP_07[17:16];
	parity[905] = INITP_07[19:18];
	parity[906] = INITP_07[21:20];
	parity[907] = INITP_07[23:22];
	parity[908] = INITP_07[25:24];
	parity[909] = INITP_07[27:26];
	parity[910] = INITP_07[29:28];
	parity[911] = INITP_07[31:30];
	parity[912] = INITP_07[33:32];
	parity[913] = INITP_07[35:34];
	parity[914] = INITP_07[37:36];
	parity[915] = INITP_07[39:38];
	parity[916] = INITP_07[41:40];
	parity[917] = INITP_07[43:42];
	parity[918] = INITP_07[45:44];
	parity[919] = INITP_07[47:46];
	parity[920] = INITP_07[49:48];
	parity[921] = INITP_07[51:50];
	parity[922] = INITP_07[53:52];
	parity[923] = INITP_07[55:54];
	parity[924] = INITP_07[57:56];
	parity[925] = INITP_07[59:58];
	parity[926] = INITP_07[61:60];
	parity[927] = INITP_07[63:62];
	parity[928] = INITP_07[65:64];
	parity[929] = INITP_07[67:66];
	parity[930] = INITP_07[69:68];
	parity[931] = INITP_07[71:70];
	parity[932] = INITP_07[73:72];
	parity[933] = INITP_07[75:74];
	parity[934] = INITP_07[77:76];
	parity[935] = INITP_07[79:78];
	parity[936] = INITP_07[81:80];
	parity[937] = INITP_07[83:82];
	parity[938] = INITP_07[85:84];
	parity[939] = INITP_07[87:86];
	parity[940] = INITP_07[89:88];
	parity[941] = INITP_07[91:90];
	parity[942] = INITP_07[93:92];
	parity[943] = INITP_07[95:94];
	parity[944] = INITP_07[97:96];
	parity[945] = INITP_07[99:98];
	parity[946] = INITP_07[101:100];
	parity[947] = INITP_07[103:102];
	parity[948] = INITP_07[105:104];
	parity[949] = INITP_07[107:106];
	parity[950] = INITP_07[109:108];
	parity[951] = INITP_07[111:110];
	parity[952] = INITP_07[113:112];
	parity[953] = INITP_07[115:114];
	parity[954] = INITP_07[117:116];
	parity[955] = INITP_07[119:118];
	parity[956] = INITP_07[121:120];
	parity[957] = INITP_07[123:122];
	parity[958] = INITP_07[125:124];
	parity[959] = INITP_07[127:126];
	parity[960] = INITP_07[129:128];
	parity[961] = INITP_07[131:130];
	parity[962] = INITP_07[133:132];
	parity[963] = INITP_07[135:134];
	parity[964] = INITP_07[137:136];
	parity[965] = INITP_07[139:138];
	parity[966] = INITP_07[141:140];
	parity[967] = INITP_07[143:142];
	parity[968] = INITP_07[145:144];
	parity[969] = INITP_07[147:146];
	parity[970] = INITP_07[149:148];
	parity[971] = INITP_07[151:150];
	parity[972] = INITP_07[153:152];
	parity[973] = INITP_07[155:154];
	parity[974] = INITP_07[157:156];
	parity[975] = INITP_07[159:158];
	parity[976] = INITP_07[161:160];
	parity[977] = INITP_07[163:162];
	parity[978] = INITP_07[165:164];
	parity[979] = INITP_07[167:166];
	parity[980] = INITP_07[169:168];
	parity[981] = INITP_07[171:170];
	parity[982] = INITP_07[173:172];
	parity[983] = INITP_07[175:174];
	parity[984] = INITP_07[177:176];
	parity[985] = INITP_07[179:178];
	parity[986] = INITP_07[181:180];
	parity[987] = INITP_07[183:182];
	parity[988] = INITP_07[185:184];
	parity[989] = INITP_07[187:186];
	parity[990] = INITP_07[189:188];
	parity[991] = INITP_07[191:190];
	parity[992] = INITP_07[193:192];
	parity[993] = INITP_07[195:194];
	parity[994] = INITP_07[197:196];
	parity[995] = INITP_07[199:198];
	parity[996] = INITP_07[201:200];
	parity[997] = INITP_07[203:202];
	parity[998] = INITP_07[205:204];
	parity[999] = INITP_07[207:206];
	parity[1000] = INITP_07[209:208];
	parity[1001] = INITP_07[211:210];
	parity[1002] = INITP_07[213:212];
	parity[1003] = INITP_07[215:214];
	parity[1004] = INITP_07[217:216];
	parity[1005] = INITP_07[219:218];
	parity[1006] = INITP_07[221:220];
	parity[1007] = INITP_07[223:222];
	parity[1008] = INITP_07[225:224];
	parity[1009] = INITP_07[227:226];
	parity[1010] = INITP_07[229:228];
	parity[1011] = INITP_07[231:230];
	parity[1012] = INITP_07[233:232];
	parity[1013] = INITP_07[235:234];
	parity[1014] = INITP_07[237:236];
	parity[1015] = INITP_07[239:238];
	parity[1016] = INITP_07[241:240];
	parity[1017] = INITP_07[243:242];
	parity[1018] = INITP_07[245:244];
	parity[1019] = INITP_07[247:246];
	parity[1020] = INITP_07[249:248];
	parity[1021] = INITP_07[251:250];
	parity[1022] = INITP_07[253:252];
	parity[1023] = INITP_07[255:254];
end

endmodule
